@@ -985,16 +985,16 @@ private:
    public:
 
       ScannerStateEntry();
-      ScannerStateEntry(int state, ScannerStateType type = INTERMEDIATE);
+      ScannerStateEntry(unsigned state, ScannerStateType type = INTERMEDIATE);
       ScannerStateEntry& operator = (const ScannerStateEntry& s);
       bool operator == (const ScannerStateEntry& s);
 
-	   int getState();
+	   unsigned getState();
       ScannerStateType getType();
 
    private:
 
-      int _state;
+      unsigned _state;
       ScannerStateType _type;
    };
 
@@ -1003,18 +1003,18 @@ class ScannerTransEntry {
    public:
 
       ScannerTransEntry();
-      ScannerTransEntry(int state, char c);
-      ScannerTransEntry(int state, char c, int fstate);
+      ScannerTransEntry(unsigned state, char c);
+      ScannerTransEntry(unsigned state, char c, unsigned fstate);
       ScannerTransEntry& operator = (const ScannerTransEntry& s);
       bool operator == (const ScannerTransEntry& s);
 
-      int getFState();
+      unsigned getFState();
 
    private:
 
-      int  _state;
+      unsigned  _state;
       char _c;
-      int _fstate;
+      unsigned _fstate;
    };
 
    class Scanner {
@@ -1042,18 +1042,18 @@ class ScannerTransEntry {
    public:
 
       StackEntry();
-      StackEntry(Symbol prod, int num, int state, Chain tval = "");
+      StackEntry(Symbol prod, unsigned num, unsigned state, Chain tval = "");
       StackEntry& operator = (const StackEntry& a);
 
-      int getState();
+      unsigned getState();
       Symbol getSymbol();
       Chain& getTval();
 
    private:
 
       Symbol _symbol;
-      int _num;
-      int _state;
+      unsigned _num;
+      unsigned _state;
       Chain _tval;
    };
 
@@ -1062,41 +1062,41 @@ class ScannerTransEntry {
    public:
 
       ActionEntry();
-      ActionEntry(Action action, int num);
+      ActionEntry(Action action, unsigned num);
       bool operator == (const ActionEntry& a);
       ActionEntry& operator = (const ActionEntry& a);
 
       Action getAction();
-      int getNum();
+      unsigned getNum();
 
    private:
 
       Action _action;
-      int _num;
+      unsigned _num;
    };
 
    ActionEntry _actionMap[950][204];
-   int _jumpMap[950][130];
+   unsigned _jumpMap[950][130];
 
    class ProdEntry {
 
    public:
 
       ProdEntry();
-      ProdEntry(int id);
-      ProdEntry(int id, Production prod, int numSymbol);
+      ProdEntry(unsigned id);
+      ProdEntry(unsigned id, Production prod, unsigned numSymbol);
       bool operator == (const ProdEntry& a);
       ProdEntry& operator = (const ProdEntry& a);
 
-      int getId();
+      unsigned getId();
       Production getProd();
-      int getNumSymbol();
+      unsigned getNumSymbol();
 
    private:
 
-      int _id;
+      unsigned _id;
       Production _prod;
-      int _numSymbol;
+      unsigned _numSymbol;
 
    };
 
@@ -1106,8 +1106,8 @@ class ScannerTransEntry {
    bool isSepSign(char c);
    bool shiftToken();
 
-   bool getAction(int state, Token token, Action& a, int& num);
-   bool getJump(int state, Production prod, int& fstate);
+   bool getAction(unsigned state, Token token, Action& a, unsigned& num);
+   bool getJump(unsigned state, Production prod, unsigned& fstate);
 
    Token _reservedToken;
    bool _isReserved;
