@@ -56,7 +56,7 @@ class CegoAction : public Cego {
 
 public:
 
-    CegoAction(CegoDistManager *pTabMng, CegoDbThreadPool *pDbPool = 0);
+    CegoAction(CegoQueryManager *pTabMng, CegoDbThreadPool *pDbPool = 0);
     ~CegoAction();
 
     void setTableSet(const Chain& tableSet);
@@ -692,7 +692,7 @@ private:
     unsigned _dataLen;
     unsigned _dataDim;
 
-    CegoDistManager* _pTabMng;
+    CegoQueryManager* _pTabMng;
     
     CegoFieldValue _fieldValue;
     CegoFieldValue _defaultValue;
