@@ -72,8 +72,6 @@ public:
     void dbQueryHistCostAction();
     
     void admThreadInfoAction();
-    void logThreadInfoAction();
-    void copyInfoAction();
 
     void buFileInfoAction();
     void buStatInfoAction();
@@ -92,20 +90,16 @@ public:
     void binModeAction();
     void plainModeAction();
 
-    void dbSessionInfoAction();
-    void listNodeAction();
-
     void startTableSetAction();
     void stopTableSetAction();
 
-    void retrieveTableSetAction();
+    void startRecoveryAction();
+    void stopRecoveryAction();
+
     void defineTableSetAction();
     void dropTableSetAction();
     void removeTableSetAction();
-    void resetTableSetAction();
     void createTableSetAction();
-    void switchTableSetAction();
-    void copyTableSetAction();
 
     void restoreTableSetAction();
     void recoverTableSetAction();
@@ -130,13 +124,6 @@ public:
     void setNumQueryLastAction();
     void setNumQueryCostAction();
 	
-    void switchSecondaryAction();
-    void switchMediatorAction();
-
-    void relocateSecondaryAction();
-    void relocateMediatorAction();
-
-    void checkTableSetAction();
     void verifyTableSetAction();
     void correctTableSetAction();
 
@@ -147,15 +134,6 @@ public:
 
     void syncTableSetAction();
 
-    void getDbSpecAction();
-
-    void getNodeListAction();
-    void getDbInfoAction();
-
-    void setTableSetNodeAction();
-
-    void copyFileAction();
-
     void exportTableAction();
     void exportTableSetAction();
     void exportTableSetStructureAction();
@@ -251,7 +229,7 @@ public:
 private:
 
     void reallocateStringBuf();
-    void handleMedResult(CegoAdminHandler::ResultType res);
+    void handleResult(CegoAdminHandler::ResultType res);
 
     bool _abortEnabled;
     bool _isAborted;
@@ -265,8 +243,6 @@ private:
     CegoAdminHandler* _pAH;
 
     Chain _tsRoot;
-    Chain _primary;
-    Chain _secondary;
 
     unsigned _sysSize;
     unsigned _tmpSize;
