@@ -94,8 +94,8 @@ void CegoAdmNet::getTableSetInfo(const Chain& tableSet,
 				 ListT<Chain>& logInfoList)
 {
     CegoAdminHandler::ResultType res;    
-    res = _pAH->medGetDetailedTableSetInfo(tableSet);
-    handleMedResult(res);
+    res = _pAH->reqGetDetailedTSInfo(tableSet);
+    handleResult(res);
         
     CegoTableObject oe;
     ListT<ListT<CegoFieldValue> > tsinfo;
@@ -195,8 +195,8 @@ void CegoAdmNet::getTableSetList(ListT<Chain>& tslist)
 {
     CegoAdminHandler::ResultType res;
     
-    res = _pAH->medGetTableSetList();
-    handleMedResult(res);
+    res = _pAH->reqGetTableSetList();
+    handleResult(res);
         
     CegoTableObject oe;
     ListT<ListT<CegoFieldValue> > info;
@@ -216,15 +216,15 @@ void CegoAdmNet::getTableSetList(ListT<Chain>& tslist)
 void CegoAdmNet::startTableSet(const Chain& tableSet, bool doCleanup, bool forceload, bool cpDump, bool noInit)
 {
     CegoAdminHandler::ResultType res;
-    res = _pAH->medStartTableSet(tableSet, doCleanup, forceload, cpDump, noInit);
-    handleMedResult(res);    
+    res = _pAH->reqStartTableSet(tableSet, doCleanup, forceload, cpDump, noInit);
+    handleResult(res);    
 }
 
 void CegoAdmNet::stopTableSet(const Chain& tableSet)
 {
     CegoAdminHandler::ResultType res;    
-    res = _pAH->medStopTableSet(tableSet);
-    handleMedResult(res);   
+    res = _pAH->reqStopTableSet(tableSet);
+    handleResult(res);   
 }
 
 void CegoAdmNet::getThreadInfo(ListT<Chain>& threadInfoList)
@@ -232,7 +232,7 @@ void CegoAdmNet::getThreadInfo(ListT<Chain>& threadInfoList)
     CegoAdminHandler::ResultType res;
     
     res = _pAH->reqThreadInfo();
-    handleMedResult(res);	
+    handleResult(res);	
 
     CegoTableObject oe;
     ListT<ListT<CegoFieldValue> > threadinfo;
@@ -264,7 +264,7 @@ void CegoAdmNet::getDbThreadInfo(ListT<Chain>& dbThreadInfoList)
     CegoAdminHandler::ResultType res;
 
     res = _pAH->reqDbThreadInfo();	
-    handleMedResult(res);
+    handleResult(res);
     
     CegoTableObject oe;
     ListT<ListT<CegoFieldValue> > dbthreadinfo;
@@ -302,7 +302,7 @@ void CegoAdmNet::getAdmThreadInfo(ListT<Chain>& admThreadInfoList)
     CegoAdminHandler::ResultType res;
     
     res = _pAH->reqAdmThreadInfo();
-    handleMedResult(res);
+    handleResult(res);
     
     CegoTableObject oe;
     ListT<ListT<CegoFieldValue> > admthreadinfo;
@@ -335,51 +335,13 @@ void CegoAdmNet::getAdmThreadInfo(ListT<Chain>& admThreadInfoList)
     }
 }
 
-void CegoAdmNet::getLogThreadInfo(ListT<Chain>& logThreadInfoList)
-{
-    CegoAdminHandler::ResultType res;
-    
-    res = _pAH->reqLogThreadInfo();
-    handleMedResult(res);
-    
-    CegoTableObject oe;
-    ListT<ListT<CegoFieldValue> > logthreadinfo;
-    
-    Chain format;
-    _pAH->getLogThreadInfo(oe, logthreadinfo, format);
-
-    ListT<CegoFieldValue> *pLogTI = logthreadinfo.First();
-    while ( pLogTI )
-    {
-	Chain id;
-	Chain numReq;
-	Chain status;
-
-	CegoFieldValue *pF = pLogTI->First();
-	if ( pF )
-	    id = pF->valAsChain();
-	pF = pLogTI->Next();
-	if ( pF )
-	    numReq = pF->valAsChain();
-	pF = pLogTI->Next();
-	if ( pF )
-	    status = pF->valAsChain();
-
-	Chain attrVal = id + Chain(":") + numReq + Chain(":") + status;
-	
-	logThreadInfoList.Insert( attrVal );
-
-	pLogTI = logthreadinfo.Next();
-    }
-}
-
 void CegoAdmNet::importTableSet(const Chain& tableSet, const Chain& impMode, const Chain& impFile)
 {
     CegoAdminHandler::ResultType res;
     bool isStructure=false;
     
     res = _pAH->reqImportTableSet(tableSet, isStructure, impFile, impMode);
-    handleMedResult(res);       
+    handleResult(res);       
 }
 
 void CegoAdmNet::exportTableSet(const Chain& tableSet, const Chain& expMode, const Chain& expFile)
@@ -387,20 +349,18 @@ void CegoAdmNet::exportTableSet(const Chain& tableSet, const Chain& expMode, con
     CegoAdminHandler::ResultType res;
     bool isStructure=false;
     res = _pAH->reqExportTableSet(tableSet, isStructure, expFile, expMode);
-    handleMedResult(res);        
+    handleResult(res);        
 }
    
 void CegoAdmNet::addDataFile(const Chain& tableSet, const Chain& fileType, const Chain& dataFile, unsigned numPages)
 {
     CegoAdminHandler::ResultType res;    
-    res = _pAH->medAddDataFile(tableSet, fileType, dataFile, numPages);
-    handleMedResult(res);
+    res = _pAH->reqAddDataFile(tableSet, fileType, dataFile, numPages);
+    handleResult(res);
 }
 
 void CegoAdmNet::defineTableSet(const Chain& tableSet, 
 				const Chain& tsRoot,
-				const Chain& primary,
-				const Chain& secondary,
 				unsigned sysSize,
 				unsigned tmpSize,
 				unsigned appSize,
@@ -410,10 +370,8 @@ void CegoAdmNet::defineTableSet(const Chain& tableSet,
 				unsigned branchId)
 {
     CegoAdminHandler::ResultType res;
-    res = _pAH->medDefineTableSet(tableSet,
+    res = _pAH->reqDefineTableSet(tableSet,
 				  tsRoot,
-				  primary,
-				  secondary,
 				  sysSize,
 				  tmpSize,
 				  appSize,
@@ -421,59 +379,31 @@ void CegoAdmNet::defineTableSet(const Chain& tableSet,
 				  logNum, 
 				  orderSize,
 				  branchId);
-    handleMedResult(res);
+    handleResult(res);
 }
 
 void CegoAdmNet::createTableSet(const Chain& tableSet)
 {
     CegoAdminHandler::ResultType res;   
-    res = _pAH->medCreateTableSet(tableSet);
-    handleMedResult(res);
+    res = _pAH->reqCreateTableSet(tableSet);
+    handleResult(res);
 }
 
 void CegoAdmNet::dropTableSet(const Chain& tableSet) 
 {
     CegoAdminHandler::ResultType res;   
-    res = _pAH->medDropTableSet(tableSet);
-    handleMedResult(res);
-}
-
-void CegoAdmNet::switchSecondary(const Chain& tableSet)
-{
-    CegoAdminHandler::ResultType res;
-    res = _pAH->medSecSwitch(tableSet);
-    handleMedResult(res);
-}
-
-void CegoAdmNet::switchMediatorAction(const Chain& tableSet)
-{
-    CegoAdminHandler::ResultType res;
-    res = _pAH->secMedSwitch(tableSet);
-    handleMedResult(res);
-}
-
-void CegoAdmNet::relocateSecondary(const Chain& tableSet, const Chain& secondary)
-{
-    CegoAdminHandler::ResultType res;
-    res = _pAH->medSecRelocate(tableSet, secondary);
-    handleMedResult(res);
-}
-
-void CegoAdmNet::relocateMediator(const Chain& tableSet, const Chain& mediator)
-{
-    CegoAdminHandler::ResultType res;
-    res = _pAH->secMedRelocate(tableSet, mediator);
-    handleMedResult(res);
+    res = _pAH->reqDropTableSet(tableSet);
+    handleResult(res);
 }
 
 void CegoAdmNet::recoverTableSet(const Chain& tableSet, const Chain& pit, unsigned long long targetlsn)
 {
     CegoAdminHandler::ResultType res;
-    res = _pAH->medRecover(tableSet, pit, targetlsn);
-    handleMedResult(res);
+    res = _pAH->reqRecover(tableSet, pit, targetlsn);
+    handleResult(res);
 }
 
-void CegoAdmNet::handleMedResult(CegoAdminHandler::ResultType res)
+void CegoAdmNet::handleResult(CegoAdminHandler::ResultType res)
 {
     Chain msg;
     _pAH->getMsg(msg);
