@@ -168,26 +168,10 @@ private:
 	    ListT<Chain> _threadSchema;
 	    CegoAdminHandler* _pAH;
 	};
-
-      	class LogPool : public Screen::Grid {
-	public:
-	    
-	    LogPool(CegoAdminHandler* pAH, Screen::Panel* pParent);
-	    ListT< ListT<Chain> > getData() { return _threadTable; };
-	    bool doRefresh() { return true; }
-	    void refresh();
-	    
-	private:
-
-	    ListT< ListT<Chain> > _threadTable;
-	    ListT<Chain> _threadSchema;
-	    CegoAdminHandler* _pAH;
-	};
       
 	CegoAdminHandler* _pAH;
 	DbPool* _pDb;
 	AdmPool* _pAdm;
-	LogPool* _pLog;	
     };
 
     ////////////////////
