@@ -512,22 +512,16 @@ void helpOverview()
     cout << "   -----------------------" << endl;
     cout << endl;
     cout << "   [t0] list tableset" << endl;
-    cout << "   [t1] retrieve tableset from '<hostname>'" << endl;
     cout << "   [t2] define tableset <tableset> <attr1>=<value1> <attr2=value2> ..." << endl;	
     cout << "   [t3] create tableset <tableset>" << endl;
     cout << "   [t4] show tableset <tableset>" << endl;
     cout << "   [t5] start tableset <tableset> [ cleanup ] [ forceload ] [ cpdump ]" << endl;
     cout << "   [t6] stop tableset <tableset>" << endl;
-    cout << "   [t7] copy tableset <tableset>" << endl;
-    cout << "   [t8] switch tableset <tableset>" << endl;
-    cout << "   [t9] switch secondary for <tableset>" << endl;
-    cout << "   [t10] switch mediator for <tableset>" << endl;
-    cout << "   [t11] relocate secondary for <tableset> to '<hostname>'" << endl;
-    cout << "   [t12] relocate mediator for <tableset> to '<hostname>'" << endl;
+    cout << "   [t7] start recovery <tableset>" << endl;
+    cout << "   [t8] stop recovery <tableset>" << endl;
     cout << "   [t13] drop tableset <tableset>" << endl;
     cout << "   [t14] remove tableset <tableset>" << endl;
     cout << "   [t15] add <app|sys|temp> datafile '<filename>' size <numpages> to <tableset>" << endl;
-    cout << "   [t16] check tableset <tableset>" << endl;
     cout << "   [t17] verify tableset <tableset>" << endl;
     cout << "   [t18] correct tableset <tableset>" << endl;
     cout << "   [t19] set checkpoint <intval> for <tableset>" << endl;
@@ -545,7 +539,6 @@ void helpOverview()
     cout << "   [t31] list logfile for <tableset>" << endl;
     cout << "   [t32] list transaction for <tableset>" << endl;
     cout << "   [t33] list object for <tableset>" << endl;
-    cout << "   [t34] reset tableset <tableset>" << endl;
     cout << "   [t35] [ enable | disable ] querycache for <tableset>" << endl;
     cout << "   [t47] show querycache for <tableset>" << endl;
     cout << "   [t36] list querycache for <tableset>" << endl;
@@ -965,15 +958,7 @@ void helpTopic(const Chain& topic)
 	cout << "list tableset" << endl;
 	cout << "-------------" << endl;
 	cout << endl;
-	cout << "   List all known tablesets on the node." << endl;
-	cout << "   The current status and assigned hosts ( mediator, primary, secondary) are also indicated." << endl;
-	cout << endl;	
-    }
-    else if ( topic == Chain("t1"))
-    {
-	cout << endl;
-	cout << "retrieve tableset from '<hostname>'" << endl;
-	cout << "-----------------------------------" << endl;
+	cout << "   List all known tablesets with current status and space usage" << endl;
 	cout << endl;	
     }
     else if ( topic == Chain("t2"))
@@ -992,16 +977,13 @@ void helpTopic(const Chain& topic)
 	cout << "   lognum          - Number of configured redolog files." << endl;
 	cout << "   sortareasize    - Size of the sort area in byte." << endl;
 	cout << "   branchid        - Number of the backup branch." << endl;
-	cout << "   primary         - Name of the primary host." << endl;
-	cout << "   secondary       - Name of the secondary host." << endl;
 	cout << endl;
 	cout << "   For a defintion statement the attributes syssize, tmpsize, appsize, logsize, lognum, sortareasize and branchid attributes are specified as integer values." << endl;
-	cout << "   The attributes tsroot, primary and secondary are specified as string values." << endl;
+	cout << "   The attribute tsroot is specified as string value." << endl;
 	cout << endl;
 	cout << "   Sample:" << endl;
 	cout << endl;
-	cout << "      define tableset ts1 tsroot='/cego/ts1' syssize=100 tmpsize=100 appsize=3000 " << endl; 
-	cout << "             logsize=100000 lognum=3 primary='geek' secondary='sam';" << endl;
+	cout << "      define tableset ts1 tsroot='/cego/ts1' syssize=100 tmpsize=100 appsize=3000 logsize=100000 lognum=3;" << endl;
 	cout << endl;
     }
     else if ( topic == Chain("t3"))
@@ -1016,16 +998,12 @@ void helpTopic(const Chain& topic)
     else if ( topic == Chain("t4"))
     {
 	cout << endl;
-	cout << "info tableset <tableset>" << endl;
+	cout << "show tableset <tableset>" << endl;
 	cout << "------------------------" << endl;
 	cout << endl;
 	cout << "   Prints a detailed listing of the current tableset configuration values" << endl;
 	cout << endl;
 	cout << "   RunState        - Running state of the tableset ( ONLINE or OFFLINE )." << endl;
-	cout << "   SyncState       - Syncing state of the tableset ( relevant for distribution mode )" << endl;
-	cout << "   Primary         - Tableset primary host." << endl;
-	cout << "   Secondary       - Tableset secondary host." << endl;
-	cout << "   Mediator        - Tableset mediator host." << endl;
 	cout << "   RootPath        - Tableset root path, all data files are located in this path." << endl;
 	cout << "   Ticket          - Backup ticket file name." << endl;
 	cout << "   InitFile        - Location of the tableset initfile." << endl;
@@ -1049,7 +1027,7 @@ void helpTopic(const Chain& topic)
 	cout << "start tableset <tableset> [ cleanup ] [ forceload ] [ cpdump ]" << endl;
 	cout << "--------------------------------------------------------------" << endl;
 	cout << endl;
-	cout << "   Starts the specified tableset on the configured primary node." << endl;
+	cout << "   Starts the specified tableset." << endl;
 	cout << "   The forceload option enforces an initial load of all available views and procedure." << endl;
 	cout << "   With cpdump, a checkpoint dump is performed, which increases consistency probability in case of system crashs during checkpoints," << endl;
         cout << "   but also slows down database performance" << endl;
@@ -1061,55 +1039,27 @@ void helpTopic(const Chain& topic)
 	cout << "stop tableset <tableset>" << endl;
 	cout << "------------------------" << endl;
 	cout << endl;
-	cout << "   Stops the specified tableset on the primary node." << endl;
+	cout << "   Stops the specified tableset." << endl;
 	cout << endl;
     }
     else if ( topic == Chain("t7"))
     {
 	cout << endl;
-	cout << "copy tableset <tableset>" << endl;
+	cout << "start recovery <tableset>" << endl;
 	cout << "------------------------" << endl;
 	cout << endl;
+	cout << "   Start recovery background process for given tableset." << endl;
+	cout << endl;
     }
     else if ( topic == Chain("t8"))
     {
 	cout << endl;
-	cout << "switch tableset <tableset>" << endl;
-	cout << "--------------------------" << endl;
+	cout << "stop recovery <tableset>" << endl;
+	cout << "------------------------" << endl;
 	cout << endl;
-    }
-    else if ( topic == Chain("t9"))
-    {
+	cout << "   Stop recovery background process for given tableset." << endl;
 	cout << endl;
-	cout << "switch secondary for <tableset>" << endl;
-	cout << "-------------------------------" << endl;
-	cout << endl;
-    }
-    else if ( topic == Chain("t10"))
-    {
-	cout << endl;
-	cout << "switch mediator for <tableset>" << endl;
-	cout << "------------------------------" << endl;
-	cout << endl;
-    }
-    else if ( topic == Chain("t11"))
-    {
-	cout << endl;
-	cout << "relocate secondary for <tableset> to '<hostname>'" << endl;
-	cout << "-------------------------------------------------" << endl;
-	cout << endl;
-	cout << "   Relocates the secondary role to the given hostname." << endl;
-	cout << endl;
-    }
-    else if ( topic == Chain("t12"))
-    {
-	cout << endl;
-	cout << "relocate mediator for <tableset> to '<hostname>'" << endl;
-	cout << "------------------------------------------------" << endl;
-	cout << endl;
-	cout << "   Relocates the mediator role to the given hostname." << endl;
-	cout << endl;
-    }
+    }    
     else if ( topic == Chain("t13"))
     {
 	cout << endl;
@@ -1137,13 +1087,6 @@ void helpTopic(const Chain& topic)
 	cout << "   Adds a new datafile with the specified size to the given tableset" << endl;
 	cout << endl;
     }
-    else if ( topic == Chain("t16"))
-    {
-	cout << endl;
-	cout << "check tableset <tableset>" << endl;
-	cout << "-------------------------" << endl;
-	cout << endl;
-    }
     else if ( topic == Chain("17"))
     {
 	cout << endl;
@@ -1311,16 +1254,6 @@ void helpTopic(const Chain& topic)
 	cout << endl;
 	cout << endl;	
     }
-    else if ( topic == Chain("t34"))
-    {
-	cout << endl;
-	cout << "reset tableset <tableset>" << endl;
-	cout << "-------------------------------------------------------------" << endl;
-	cout << endl;
-	cout << "   Tries to reset a tableset to a defined offline state on the primary node." << endl;
-	cout << "   The command just should be executed in case of any undetermined exception." << endl;	
-	cout << endl;	
-    }
     else if ( topic == Chain("t35"))
     {
 	cout << endl;
