@@ -30,9 +30,8 @@
 // CEGO INCLUDES
 #include "CegoAdminHandler.h"
 #include "CegoDatabaseManager.h"
-#include "CegoDistManager.h"
+#include "CegoQueryManager.h"
 #include "CegoDbThreadPool.h"
-#include "CegoLogThreadPool.h"
 
 class CegoAdminThreadPool;
 
@@ -41,7 +40,7 @@ class CegoAdminThread : public Thread {
 public:
     
     CegoAdminThread();
-    CegoAdminThread(CegoAdminThreadPool *pPool, CegoDatabaseManager *pDBMng, CegoDbThreadPool *pDbPool, CegoLogThreadPool *pLogPool);
+    CegoAdminThread(CegoAdminThreadPool *pPool, CegoDatabaseManager *pDBMng, CegoDbThreadPool *pDbPool);
     ~CegoAdminThread();
     
     const Chain& lastAction() const;
@@ -94,13 +93,14 @@ private:
 	Chain _result;
     };
 
-
-    void copyTableSet(unsigned copyId, const Chain& tableSet, const Chain& secondary, const Chain& mediator, const Chain& user, const Chain& passwd, bool copyOnline);
     
     void serveSession(CegoAdminHandler *pAH);
     bool serveRequest(CegoAdminHandler *pAH, CegoAdminHandler::RequestType reqType);
-    
-    void srvRetrieveTableSet(CegoAdminHandler *pAH);
+
+    void srvGetTableSetList(CegoAdminHandler *pAH);
+    void srvGetTSInfo(CegoAdminHandler *pAH);
+    void srvGetDetailedTSInfo(CegoAdminHandler *pAH);
+
     void srvLockInfo(CegoAdminHandler *pAH);
     void srvLockStat(CegoAdminHandler *pAH);
     void srvParameterInfo(CegoAdminHandler *pAH);
@@ -118,10 +118,7 @@ private:
     void srvNumQueryCost(CegoAdminHandler *pAH);
     
     void srvAdmThreadInfo(CegoAdminHandler *pAH);
-    void srvLogThreadInfo(CegoAdminHandler *pAH);
     void srvDbThreadAbort(CegoAdminHandler *pAH);
-    void srvDbSessionInfo(CegoAdminHandler *pAH);
-    void srvCopyInfo(CegoAdminHandler *pAH);
 
     void srvShowQueryCache(CegoAdminHandler *pAH);
     void srvListQueryCache(CegoAdminHandler *pAH);
@@ -140,8 +137,6 @@ private:
     void srvDropTableSet(CegoAdminHandler *pAH);
     void srvStartTableSet(CegoAdminHandler *pAH);
     void srvStopTableSet(CegoAdminHandler *pAH);
-    void srvVerifyTableSet(CegoAdminHandler *pAH);
-    void srvCorrectTableSet(CegoAdminHandler *pAH);
     void srvDumpObject(CegoAdminHandler *pAH);
     void srvSetLogMng(CegoAdminHandler *pAH);
     void srvShowLogMng(CegoAdminHandler *pAH);
@@ -162,21 +157,12 @@ private:
     void srvStopRecovery(CegoAdminHandler *pAH);
     void srvGetDbSpec(CegoAdminHandler *pAH);
     void srvGetDbInfo(CegoAdminHandler *pAH);
-    void srvGetTSInfo(CegoAdminHandler *pAH);
-
-    void srvGetDetailedTSInfo(CegoAdminHandler *pAH);
+    
     void srvGetArchLogInfo(CegoAdminHandler *pAH);
     void srvGetTransactionInfo(CegoAdminHandler *pAH);
     void srvGetBUStatInfo(CegoAdminHandler *pAH);
 
-    void srvPropTSInfo(CegoAdminHandler *pAH);
-    void srvCopyTableSet(CegoAdminHandler *pAH);
-    void srvCopyFile(CegoAdminHandler *pAH);
-    void srvGetNodeList(CegoAdminHandler *pAH);
-    void srvSetTableSetNode(CegoAdminHandler *pAH);
     void srvSetLSN(CegoAdminHandler *pAH);
-    void srvSetRunState(CegoAdminHandler *pAH);
-    void srvSetSyncState(CegoAdminHandler *pAH);
     void srvExportTableSet(CegoAdminHandler *pAH);
     void srvImportTableSet(CegoAdminHandler *pAH);
     void srvExportTable(CegoAdminHandler *pAH);
@@ -210,7 +196,6 @@ private:
     
     void srvRestore(CegoAdminHandler *pAH);
     void srvRecover(CegoAdminHandler *pAH);
-    void srvSecSwitch(CegoAdminHandler *pAH);
 
     void srvEnableTableCache(CegoAdminHandler *pAH);
     void srvDisableTableCache(CegoAdminHandler *pAH);
@@ -218,7 +203,24 @@ private:
     void srvEnableQueryCache(CegoAdminHandler *pAH);
     void srvDisableQueryCache(CegoAdminHandler *pAH);
 
+    void srvVerifyTableSet(CegoAdminHandler *pAH);
+    void srvCorrectTableSet(CegoAdminHandler *pAH);
+
+    void srvEnableArchLog(CegoAdminHandler *pAH);
+    void srvDisableArchLog(CegoAdminHandler *pAH);
+
+    void srvEnableAppendMode(CegoAdminHandler *pAH);
+    void srvDisableAppendMode(CegoAdminHandler *pAH);
+
+    void srvEnableAutoCorrect(CegoAdminHandler *pAH);
+    void srvDisableAutoCorrect(CegoAdminHandler *pAH);
+
+    void srvResetBUStat(CegoAdminHandler *pAH);
+
+    
     // mediator services
+
+    /*
     void medNotify(CegoAdminHandler *pAH);
     void medDefineTableSet(CegoAdminHandler *pAH);
     void medRemoveTableSet(CegoAdminHandler *pAH);
@@ -236,17 +238,14 @@ private:
     void medAddArchLog(CegoAdminHandler *pAH);
     void medRemoveArchLog(CegoAdminHandler *pAH);
     void medAddDatafile(CegoAdminHandler *pAH);
-    void medVerifyTableSet(CegoAdminHandler *pAH);
-    void medCorrectTableSet(CegoAdminHandler *pAH);
 
-    void medGetTableSetList(CegoAdminHandler *pAH);
     void medGetDetailedTableSetInfo(CegoAdminHandler *pAH);
     void medGetArchLogInfo(CegoAdminHandler *pAH);
 
     void medGetObjectInfo(CegoAdminHandler *pAH);
     void medGetTransactionInfo(CegoAdminHandler *pAH);
     void medGetBUStatInfo(CegoAdminHandler *pAH);
-    void medResetBUStat(CegoAdminHandler *pAH);
+
 
     void medBeginBackup(CegoAdminHandler *pAH);
     void medExecuteBackup(CegoAdminHandler *pAH);
@@ -258,21 +257,12 @@ private:
 
     void medSecRelocate(CegoAdminHandler *pAH);
 
-    void medCheckTableSet(CegoAdminHandler *pAH);
-
-    void medEnableArchLog(CegoAdminHandler *pAH);
-    void medDisableArchLog(CegoAdminHandler *pAH);
-
-    void medEnableAppendMode(CegoAdminHandler *pAH);
-    void medDisableAppendMode(CegoAdminHandler *pAH);
-
-    void medEnableAutoCorrect(CegoAdminHandler *pAH);
-    void medDisableAutoCorrect(CegoAdminHandler *pAH);
-
     // secondary services
     void secMedSwitch(CegoAdminHandler *pAH);
     void secMedRelocate(CegoAdminHandler *pAH);
 
+    */
+    
     CegoAdminHandler* getSession(const Chain& role, const Chain& hostname, const Chain& user, const Chain& pwd);
     void closeSession(CegoAdminHandler* pAH);
 
@@ -299,10 +289,9 @@ private:
     CegoDatabaseManager* _pDBMng;
     CegoAdminThreadPool* _pPool;
     NetHandler* _pRequest;
-    CegoDistManager* _pTabMng;
+    CegoQueryManager* _pTabMng;
 
     CegoDbThreadPool* _pDbPool;
-    CegoLogThreadPool* _pLogPool;
 
     Chain _lastAction;
 
