@@ -22,12 +22,6 @@
 #include <iostream> 
 #include <stdlib.h> 
 
-// improved bsd random functions still not supported for mingw
-#ifdef HAVE_MINGW
-#define srandom srand
-#define random rand
-#endif
-
 // LFC INCLUDES
 #include <lfcbase/Exception.h>
 #include <lfcbase/GetLongOpt.h>
