@@ -1222,10 +1222,8 @@ void CegoBufferPool::logIt(unsigned tabSetId, CegoLogRecord& lr, CegoLockHandler
 	    
 	    if ( res == CegoLogManager::LOG_ERROR )
 	    {
-		Chain tableSet = getTabSetName(tabSetId);
-		setTableSetSyncState(tableSet, XML_LOG_LOSS_VALUE);
-		
-		throw Exception(EXLOC, Chain("Cannot write to log"));
+		Chain tableSet = getTabSetName(tabSetId);		
+		throw Exception(EXLOC, Chain("Cannot write to log for tableset ") + tableSet);
 	    }
 	}
 	catch ( Exception e )
