@@ -35,7 +35,7 @@ class CegoCaseCond {
 public:
 
     CegoCaseCond();
-    CegoCaseCond(char* buf, CegoDistManager *pGTM, CegoProcBlock *pBlock, unsigned tabSetId);
+    CegoCaseCond(char* buf, CegoQueryManager *pGTM, CegoProcBlock *pBlock, unsigned tabSetId);
     ~CegoCaseCond();
 
     void cleanUp();    
@@ -71,7 +71,7 @@ public:
     Chain dbFormat(CegoDatabaseFormater *pForm) const;
     
     void encode(char *buf, CegoProcBlock *pBlock);
-    void decode(char *buf, CegoDistManager* pGTM, CegoProcBlock *pBlock, unsigned tabSetId);
+    void decode(char *buf, CegoQueryManager* pGTM, CegoProcBlock *pBlock, unsigned tabSetId);
     unsigned getEncodingLength(CegoProcBlock *pBlock) const;
 
     void getPlanList(ListT<Element*>& planList);
