@@ -38,33 +38,33 @@ class CegoDbThreadPool : public Thread {
     enum ThreadState { STARTING, READY, CONNECTED, BUSY };
   
     CegoDbThreadPool();
-    CegoDbThreadPool(int poolLimit, CegoDatabaseManager *pDBMng, CegoDbHandler::ProtocolType protType);
+    CegoDbThreadPool(unsigned poolLimit, CegoDatabaseManager *pDBMng, CegoDbHandler::ProtocolType protType);
     ~CegoDbThreadPool();
 
     void* job(void* arg);
     void syncToReady();
-    void loadObjects(int tabSetId);
-    void unloadObjects(int tabSetId);
-    void invalidateObject(int tabSetId, const Chain& objName, CegoObject::ObjectType type);
-    int getPoolLimit() const;
-    void getThreadInfo(int i, unsigned long long& numRequest, unsigned long long& numQueryRequest, unsigned long long& threadLoad, unsigned long long& allocatedSort, ThreadState& state, Chain& lastAction);
-    void getThreadHistory(int i, ListT<CegoDbThread::QueryEntry>& queryList);
-    void getQueryHistoryLast(int numLast, ListT<CegoDbThread::QueryEntry>& queryList);
-    void getQueryHistoryCost(int numLast, ListT<CegoDbThread::QueryEntry>& queryList);
-    void setState(int i, ThreadState state);
-    void incNumRequest(int i);
-    void incNumQueryRequest(int i);
-    void addThreadIdle(int i, unsigned long long usec);
-    void setTid(int i, unsigned long long tid);
-    void setThreadState(int i, CegoDbThreadPool::ThreadState state);
-    void abortThread(int i);
+    void loadObjects(unsigned tabSetId);
+    void unloadObjects(unsigned tabSetId);
+    void invalidateObject(unsigned tabSetId, const Chain& objName, CegoObject::ObjectType type);
+    unsigned getPoolLimit() const;
+    void getThreadInfo(unsigned i, unsigned long long& numRequest, unsigned long long& numQueryRequest, unsigned long long& threadLoad, unsigned long long& allocatedSort, ThreadState& state, Chain& lastAction);
+    void getThreadHistory(unsigned i, ListT<CegoDbThread::QueryEntry>& queryList);
+    void getQueryHistoryLast(unsigned numLast, ListT<CegoDbThread::QueryEntry>& queryList);
+    void getQueryHistoryCost(unsigned numLast, ListT<CegoDbThread::QueryEntry>& queryList);
+    void setState(unsigned i, ThreadState state);
+    void incNumRequest(unsigned i);
+    void incNumQueryRequest(unsigned i);
+    void addThreadIdle(unsigned i, unsigned long long usec);
+    void setTid(unsigned i, unsigned long long tid);
+    void setThreadState(unsigned i, CegoDbThreadPool::ThreadState state);
+    void abortThread(unsigned i);
     NetHandler* nextRequest();
     bool isBusy();
     bool isTerminated();
-    void getLockStat(Chain& lockName, int& lockCount, unsigned long long &numRdLock, unsigned long long &numWrLock, unsigned long long &sumRdDelay, unsigned long long &sumWrDelay);
-    void getAggThreadLockStat(Chain& lockGroup, int& numLock, int& lockCount, unsigned long long &numRdLock, unsigned long long &numWrLock, unsigned long long &sumRdDelay, unsigned long long &sumWrDelay);
-    void P(int i);
-    void V(int i);
+    void getLockStat(Chain& lockName, unsigned& lockCount, unsigned long long &numRdLock, unsigned long long &numWrLock, unsigned long long &sumRdDelay, unsigned long long &sumWrDelay);
+    void getAggThreadLockStat(Chain& lockGroup, unsigned& numLock, unsigned& lockCount, unsigned long long &numRdLock, unsigned long long &numWrLock, unsigned long long &sumRdDelay, unsigned long long &sumWrDelay);
+    void P(unsigned i);
+    void V(unsigned i);
     
  private:
 
@@ -77,11 +77,11 @@ class CegoDbThreadPool : public Thread {
     unsigned long long* _numQueryRequest;
     unsigned long long* _threadIdle[THRMNG_NUMLOADSAMPLE];
     unsigned long long* _threadLoad;
-    int _samplePos;
+    unsigned _samplePos;
     CegoDbThread** _threadList;
-    int _poolLimit;
-    int _dataPortNo;
-    int _maxSendLen;
+    unsigned _poolLimit;
+    unsigned _dataPortNo;
+    unsigned _maxSendLen;
     Chain _dataHostName;
     bool _terminated;
     bool _joined;
