@@ -29,7 +29,7 @@
 #include "CegoTerm.h"
 #include "CegoProcStmt.h"
 
-class CegoDistManager;
+class CegoQueryManager;
 
 class CegoExpr {
 
@@ -38,7 +38,7 @@ public:
     enum ExpType { ADD, SUB, TERM, CONCAT  };
     
     CegoExpr();
-    CegoExpr(char* buf, CegoDistManager *pGTM, CegoProcBlock *pBlock, unsigned tabSetId);
+    CegoExpr(char* buf, CegoQueryManager *pGTM, CegoProcBlock *pBlock, unsigned tabSetId);
     CegoExpr(CegoExpr *pExpr, CegoTerm *pTerm, ExpType expType, const Chain& alias = Chain());
     CegoExpr(CegoTerm *pTerm, const Chain& alias = Chain());
 
@@ -90,7 +90,7 @@ public:
     friend ostream& operator << (ostream& s, const CegoExpr& e);
 
     void encode(char *buf, CegoProcBlock *pBlock);
-    void decode(char *buf, CegoDistManager *pGTM, CegoProcBlock *pBlock, unsigned tabSetId);
+    void decode(char *buf, CegoQueryManager *pGTM, CegoProcBlock *pBlock, unsigned tabSetId);
     unsigned getEncodingLength(CegoProcBlock *pBlock) const;
 
     void getPlanList(ListT<Element*>& planList);
