@@ -33,7 +33,7 @@
 #include <string.h>
 #include <stdlib.h>
 
-CegoFactor::CegoFactor(char* buf, CegoDistManager *pGTM, CegoProcBlock *pBlock, unsigned tabSetId)
+CegoFactor::CegoFactor(char* buf, CegoQueryManager *pGTM, CegoProcBlock *pBlock, unsigned tabSetId)
 {
     _pAttrDesc = 0;
     _pExpr = 0;
@@ -1213,7 +1213,7 @@ void CegoFactor::encode(char *buf, CegoProcBlock *pBlock)
     }
 }
 
-void CegoFactor::decode(char *buf, CegoDistManager* pGTM, CegoProcBlock *pBlock, unsigned tabSetId)
+void CegoFactor::decode(char *buf, CegoQueryManager* pGTM, CegoProcBlock *pBlock, unsigned tabSetId)
 {
     char* pE = (char*)buf;
 
