@@ -25,7 +25,7 @@
 // CEGO INCLUDES
 #include "CegoFunction.h"
 #include "CegoExpr.h"
-#include "CegoDistManager.h"
+#include "CegoQueryManager.h"
 #include "CegoXMLdef.h"
 #include "CegoDatabaseFormater.h"
 #include "CegoProcedure.h"
@@ -50,7 +50,7 @@ CegoFunction::CegoFunction(CegoFunction::FunctionType type, ListT<CegoExpr*>& ex
     _type = type;
 }
 
-CegoFunction::CegoFunction(char* buf, CegoDistManager *pTabMng, CegoProcBlock *pBlock, unsigned tabSetId)
+CegoFunction::CegoFunction(char* buf, CegoQueryManager *pTabMng, CegoProcBlock *pBlock, unsigned tabSetId)
 {
     _pTabMng = pTabMng;
     _tabSetId = tabSetId;
@@ -58,14 +58,14 @@ CegoFunction::CegoFunction(char* buf, CegoDistManager *pTabMng, CegoProcBlock *p
     _pProc = 0;
 }
 
-CegoFunction::CegoFunction(CegoDistManager* pTabMng, unsigned tabSetId, CegoFunction::FunctionType type)
+CegoFunction::CegoFunction(CegoQueryManager* pTabMng, unsigned tabSetId, CegoFunction::FunctionType type)
 {
     _pTabMng = pTabMng;
     _tabSetId = tabSetId;
     _type = type;
 }
 
-CegoFunction::CegoFunction(CegoDistManager* pTabMng, unsigned tabSetId, const Chain& funcName, ListT<CegoExpr*>& exprList)
+CegoFunction::CegoFunction(CegoQueryManager* pTabMng, unsigned tabSetId, const Chain& funcName, ListT<CegoExpr*>& exprList)
 {
     _pTabMng = pTabMng;
     _exprList = exprList;
@@ -2395,7 +2395,7 @@ void CegoFunction::encode(char *buf, CegoProcBlock *pBlock)
     }
 }
 
-void CegoFunction::decode(char *buf, CegoDistManager* pGTM, CegoProcBlock *pBlock, unsigned tabSetId)
+void CegoFunction::decode(char *buf, CegoQueryManager* pGTM, CegoProcBlock *pBlock, unsigned tabSetId)
 {
     char* pE = (char*)buf;
 
