@@ -41,6 +41,6 @@ public:
  private:
 
     AVLTreeT<CegoGroupNode>* _pAVL;
-    ListT<int> _avgIdxList;
+    ListT<unsigned> _avgIdxList;
 };
 #endif
