@@ -23,9 +23,9 @@
 #include "CegoOutput.h"
 #include "CegoTypeConverter.h"
 
-CegoJDBCInfo::CegoJDBCInfo(CegoDistManager* pTabMng, CegoDbHandler* pDbHandle)
+CegoJDBCInfo::CegoJDBCInfo(CegoQueryManager* pQueryMng, CegoDbHandler* pDbHandle)
 {
-    _pTabMng = pTabMng;
+    _pQueryMng = pQueryMng;
     _pDbHandle = pDbHandle;
 }
 
@@ -35,7 +35,7 @@ CegoJDBCInfo::~CegoJDBCInfo()
 
 void CegoJDBCInfo::checkAccess() const
 {
-    if ( _pTabMng->getDBMng()->verifyJDBC(_pTabMng->getUser()) == false )
+    if ( _pQueryMng->getDBMng()->verifyJDBC(_pQueryMng->getUser()) == false )
     {
 	throw Exception(EXLOC, Chain("User not authorized for JDBC information"));	
     }
@@ -59,7 +59,7 @@ void CegoJDBCInfo::handleRequest(const ListT<Chain>& argList) const
 	    o.headOut();
 	    
 	    ListT<CegoFieldValue> fa;
-	    fa.Insert( CegoFieldValue(VARCHAR_TYPE, _pTabMng->getDBMng()->getDBName() ) );
+	    fa.Insert( CegoFieldValue(VARCHAR_TYPE, _pQueryMng->getDBMng()->getDBName() ) );
 	    o.rowOut(fa);
 	    
 	    o.tailOut();
@@ -69,7 +69,7 @@ void CegoJDBCInfo::handleRequest(const ListT<Chain>& argList) const
 	    checkAccess();
 
 	    ListT<Chain> tsList;
-	    _pTabMng->getDBMng()->getTableSetList(tsList);
+	    _pQueryMng->getDBMng()->getTableSetList(tsList);
 	    
 	    ListT<CegoField> schema;
 	    schema.Insert( CegoField("JDBC", "JDBC", "TABLE_SCHEM", VARCHAR_TYPE, MAX_OBJNAME_LEN));
@@ -137,13 +137,15 @@ void CegoJDBCInfo::handleRequest(const ListT<Chain>& argList) const
 		o.headOut();
 
 		ListT<Chain> tabList;
-		_pTabMng->getDistObjectList(*pTS, CegoObject::TABLE, tabList);
+
+		unsigned tabSetId = _pQueryMng->getDBMng()->getTabSetId(*pTS);
+		_pQueryMng->getObjectList(tabSetId, CegoObject::TABLE, tabList);
 
 		Chain *pS = tabList.First();
 		while ( pS )
 		{
 		    ListT<CegoFieldValue> f1;
-		    f1.Insert( CegoFieldValue(VARCHAR_TYPE, _pTabMng->getDBMng()->getDBName()));
+		    f1.Insert( CegoFieldValue(VARCHAR_TYPE, _pQueryMng->getDBMng()->getDBName()));
 		    f1.Insert( CegoFieldValue(VARCHAR_TYPE, *pTS));
 		    f1.Insert( CegoFieldValue(VARCHAR_TYPE, *pS));
 		    f1.Insert( CegoFieldValue(VARCHAR_TYPE, Chain("TABLE")));
@@ -190,14 +192,16 @@ void CegoJDBCInfo::handleRequest(const ListT<Chain>& argList) const
 		
 		o.headOut();
 
+		unsigned tabSetId = _pQueryMng->getDBMng()->getTabSetId(*pTS);
+		
 		ListT<Chain> viewList;
-		_pTabMng->getDistObjectList(*pTS, CegoObject::VIEW, viewList);
+		_pQueryMng->getObjectList(tabSetId, CegoObject::VIEW, viewList);
 				
 		Chain *pS = viewList.First();
 		while ( pS )
 		{
 		    ListT<CegoFieldValue> f1;
-		    f1.Insert( CegoFieldValue(VARCHAR_TYPE, _pTabMng->getDBMng()->getDBName()));
+		    f1.Insert( CegoFieldValue(VARCHAR_TYPE, _pQueryMng->getDBMng()->getDBName()));
 		    f1.Insert( CegoFieldValue(VARCHAR_TYPE, *pTS));
 		    f1.Insert( CegoFieldValue(VARCHAR_TYPE, *pS));
 		    f1.Insert( CegoFieldValue(VARCHAR_TYPE, Chain("VIEW")));
@@ -227,7 +231,10 @@ void CegoJDBCInfo::handleRequest(const ListT<Chain>& argList) const
 	    if ( pTS )
 	    {
 		ListT<Chain> objList;
-		_pTabMng->getDistObjectList(*pTS, CegoObject::PROCEDURE, objList);
+
+		unsigned tabSetId = _pQueryMng->getDBMng()->getTabSetId(*pTS);
+		
+		_pQueryMng->getObjectList(tabSetId, CegoObject::PROCEDURE, objList);
 				
 		ListT<CegoField> schema;
 		schema.Insert( CegoField("JDBC", "JDBC", "PROCEDURE_CAT", VARCHAR_TYPE, MAX_OBJNAME_LEN));
@@ -249,7 +256,7 @@ void CegoJDBCInfo::handleRequest(const ListT<Chain>& argList) const
 		while ( pS )
 		{
 		    ListT<CegoFieldValue> f1;
-		    f1.Insert( CegoFieldValue(VARCHAR_TYPE, _pTabMng->getDBMng()->getDBName()));
+		    f1.Insert( CegoFieldValue(VARCHAR_TYPE, _pQueryMng->getDBMng()->getDBName()));
 		    f1.Insert( CegoFieldValue(VARCHAR_TYPE, *pTS));
 		    f1.Insert( CegoFieldValue(VARCHAR_TYPE, *pS));
 		    f1.Insert( CegoFieldValue());
@@ -285,7 +292,9 @@ void CegoJDBCInfo::handleRequest(const ListT<Chain>& argList) const
 		ListT<CegoAliasObject> aliasList;
 		unsigned numInvalid;
 
-		_pTabMng->getDistObjectByTableList(*pTS, *pTable, idxList, btreeList, keyList, checkList, triggerList, aliasList, numInvalid);
+		unsigned tabSetId = _pQueryMng->getDBMng()->getTabSetId(*pTS);
+		
+		_pQueryMng->getObjectListByTable(tabSetId, *pTable, idxList, btreeList, keyList, checkList, triggerList, aliasList, numInvalid);
 		
 		ListT<CegoField> schema;
 		schema.Insert( CegoField("JDBC", "JDBC", "TABLE_CAT", VARCHAR_TYPE, MAX_OBJNAME_LEN));
@@ -307,14 +316,14 @@ void CegoJDBCInfo::handleRequest(const ListT<Chain>& argList) const
 		    if ( pIdx->getType() == CegoObject::PAVLTREE )
 		    {
 			CegoTableObject oe;
-			_pTabMng->getDistObject(*pTS, pIdx->getName(), CegoObject::AVLTREE, oe);
+			_pQueryMng->getObject(tabSetId, pIdx->getName(), CegoObject::AVLTREE, oe);
 			
 			unsigned i=1;
 			CegoField *pF = oe.getSchema().First();
 			while ( pF )
 			{
 			    ListT<CegoFieldValue> f1;
-			    f1.Insert( CegoFieldValue(VARCHAR_TYPE, _pTabMng->getDBMng()->getDBName()));
+			    f1.Insert( CegoFieldValue(VARCHAR_TYPE, _pQueryMng->getDBMng()->getDBName()));
 			    f1.Insert( CegoFieldValue(VARCHAR_TYPE, *pTS));
 			    f1.Insert( CegoFieldValue(VARCHAR_TYPE, oe.getTabName()));
 			    f1.Insert( CegoFieldValue(VARCHAR_TYPE, pF->getAttrName()));
@@ -335,14 +344,14 @@ void CegoJDBCInfo::handleRequest(const ListT<Chain>& argList) const
 			if ( pBTree->getType() == CegoObject::PBTREE )
 			{
 			    CegoBTreeObject oe;
-			    _pTabMng->getDistObject(*pTS, pBTree->getName(), CegoObject::BTREE, oe);
+			    _pQueryMng->getObject(tabSetId, pBTree->getName(), CegoObject::BTREE, oe);
 			    
 			    unsigned i=1;
 			    CegoField *pF = oe.getSchema().First();
 			    while ( pF )
 			    {
 				ListT<CegoFieldValue> f1;
-				f1.Insert( CegoFieldValue(VARCHAR_TYPE, _pTabMng->getDBMng()->getDBName()));
+				f1.Insert( CegoFieldValue(VARCHAR_TYPE, _pQueryMng->getDBMng()->getDBName()));
 				f1.Insert( CegoFieldValue(VARCHAR_TYPE, *pTS));
 				f1.Insert( CegoFieldValue(VARCHAR_TYPE, oe.getTabName()));
 				f1.Insert( CegoFieldValue(VARCHAR_TYPE, pF->getAttrName()));
@@ -382,7 +391,9 @@ void CegoJDBCInfo::handleRequest(const ListT<Chain>& argList) const
 		ListT<CegoAliasObject> aliasList;
 		unsigned numInvalid;
 
-		_pTabMng->getDistObjectByTableList(*pTS, *pTable, idxList, btreeList, keyList, checkList, triggerList, aliasList, numInvalid);
+		unsigned tabSetId = _pQueryMng->getDBMng()->getTabSetId(*pTS);
+		
+		_pQueryMng->getObjectListByTable(tabSetId, *pTable, idxList, btreeList, keyList, checkList, triggerList, aliasList, numInvalid);
 
 		ListT<CegoField> schema;
  		schema.Insert( CegoField("JDBC", "JDBC", "PKTABLE_CAT", VARCHAR_TYPE, MAX_OBJNAME_LEN));
@@ -412,7 +423,7 @@ void CegoJDBCInfo::handleRequest(const ListT<Chain>& argList) const
 		    if ( pKey->getType() == CegoObject::FKEY )
 		    {
 			CegoKeyObject ko;
-			_pTabMng->getDistObject(*pTS, pKey->getName(), CegoObject::FKEY, ko);
+			_pQueryMng->getObject(tabSetId, pKey->getName(), CegoObject::FKEY, ko);
 			
 			unsigned i=1;
 			CegoField *pKF = ko.getKeySchema().First();
@@ -420,11 +431,11 @@ void CegoJDBCInfo::handleRequest(const ListT<Chain>& argList) const
 			while ( pKF && pRF)
 			{
 			    ListT<CegoFieldValue> f1;
-			    f1.Insert( CegoFieldValue(VARCHAR_TYPE, _pTabMng->getDBMng()->getDBName()));
+			    f1.Insert( CegoFieldValue(VARCHAR_TYPE, _pQueryMng->getDBMng()->getDBName()));
 			    f1.Insert( CegoFieldValue(VARCHAR_TYPE, *pTS));
 			    f1.Insert( CegoFieldValue(VARCHAR_TYPE, ko.getTabName()));
 			    f1.Insert( CegoFieldValue(VARCHAR_TYPE, pKF->getAttrName()));
-			    f1.Insert( CegoFieldValue(VARCHAR_TYPE, _pTabMng->getDBMng()->getDBName()));
+			    f1.Insert( CegoFieldValue(VARCHAR_TYPE, _pQueryMng->getDBMng()->getDBName()));
 			    f1.Insert( CegoFieldValue(VARCHAR_TYPE, *pTS));
 			    f1.Insert( CegoFieldValue(VARCHAR_TYPE, ko.getRefTable()));
 			    f1.Insert( CegoFieldValue(VARCHAR_TYPE, pRF->getAttrName()));
@@ -468,7 +479,9 @@ void CegoJDBCInfo::handleRequest(const ListT<Chain>& argList) const
 		ListT<CegoAliasObject> aliasList;
 		unsigned numInvalid;
 
-		_pTabMng->getDistObjectByTableList(*pTS, *pTable, idxList, btreeList, keyList, checkList, triggerList, aliasList, numInvalid);
+		unsigned tabSetId = _pQueryMng->getDBMng()->getTabSetId(*pTS);
+		
+		_pQueryMng->getObjectListByTable(tabSetId, *pTable, idxList, btreeList, keyList, checkList, triggerList, aliasList, numInvalid);
 
 		ListT<CegoField> schema;
 
@@ -499,7 +512,7 @@ void CegoJDBCInfo::handleRequest(const ListT<Chain>& argList) const
 		    if ( pKey->getType() == CegoObject::FKEY )
 		    {
 			CegoKeyObject ko;
-			_pTabMng->getDistObject(*pTS, pKey->getName(), CegoObject::FKEY, ko);
+			_pQueryMng->getObject(tabSetId, pKey->getName(), CegoObject::FKEY, ko);
 			
 			unsigned i=1;
 			CegoField *pKF = ko.getKeySchema().First();
@@ -507,11 +520,11 @@ void CegoJDBCInfo::handleRequest(const ListT<Chain>& argList) const
 			while ( pKF && pRF)
 			{
 			    ListT<CegoFieldValue> f1;
-			    f1.Insert( CegoFieldValue(VARCHAR_TYPE, _pTabMng->getDBMng()->getDBName()));
+			    f1.Insert( CegoFieldValue(VARCHAR_TYPE, _pQueryMng->getDBMng()->getDBName()));
 			    f1.Insert( CegoFieldValue(VARCHAR_TYPE, *pTS));
 			    f1.Insert( CegoFieldValue(VARCHAR_TYPE, ko.getTabName()));
 			    f1.Insert( CegoFieldValue(VARCHAR_TYPE, pKF->getAttrName()));
-			    f1.Insert( CegoFieldValue(VARCHAR_TYPE, _pTabMng->getDBMng()->getDBName()));
+			    f1.Insert( CegoFieldValue(VARCHAR_TYPE, _pQueryMng->getDBMng()->getDBName()));
 			    f1.Insert( CegoFieldValue(VARCHAR_TYPE, *pTS));
 			    f1.Insert( CegoFieldValue(VARCHAR_TYPE, ko.getRefTable()));
 			    f1.Insert( CegoFieldValue(VARCHAR_TYPE, pRF->getAttrName()));
@@ -556,7 +569,9 @@ void CegoJDBCInfo::handleRequest(const ListT<Chain>& argList) const
 		ListT<CegoAliasObject> aliasList;
 		unsigned numInvalid;
 
-		_pTabMng->getDistObjectByTableList(*pTS, *pTable, idxList, btreeList, keyList, checkList, triggerList, aliasList, numInvalid);
+		unsigned tabSetId = _pQueryMng->getDBMng()->getTabSetId(*pTS);
+		
+		_pQueryMng->getObjectListByTable(tabSetId, *pTable, idxList, btreeList, keyList, checkList, triggerList, aliasList, numInvalid);
 
 		ListT<CegoField> schema;
 
@@ -584,14 +599,14 @@ void CegoJDBCInfo::handleRequest(const ListT<Chain>& argList) const
 		while ( pIdx )
 		{	    
 		    CegoTableObject io;
-		    _pTabMng->getDistObject(*pTS, pIdx->getName(), CegoObject::AVLTREE, io);
+		    _pQueryMng->getObject(tabSetId, pIdx->getName(), CegoObject::AVLTREE, io);
 		    
 		    unsigned i=1;
 		    CegoField *pIF = io.getSchema().First();
 		    while ( pIF)
 		    {
 			ListT<CegoFieldValue> f1;
-			f1.Insert( CegoFieldValue(VARCHAR_TYPE, _pTabMng->getDBMng()->getDBName()));
+			f1.Insert( CegoFieldValue(VARCHAR_TYPE, _pQueryMng->getDBMng()->getDBName()));
 			f1.Insert( CegoFieldValue(VARCHAR_TYPE, *pTS));
 			f1.Insert( CegoFieldValue(VARCHAR_TYPE, io.getTabName()));
 			
@@ -622,14 +637,14 @@ void CegoJDBCInfo::handleRequest(const ListT<Chain>& argList) const
 		while ( pBTree )
 		{		   
 		    CegoBTreeObject bto;
-		    _pTabMng->getDistObject(*pTS, pBTree->getName(), CegoObject::BTREE, bto);
+		    _pQueryMng->getObject(tabSetId, pBTree->getName(), CegoObject::BTREE, bto);
 		    
 		    unsigned i=1;
 		    CegoField *pIF = bto.getSchema().First();
 		    while ( pIF)
 		    {
 			ListT<CegoFieldValue> f1;
-			f1.Insert( CegoFieldValue(VARCHAR_TYPE, _pTabMng->getDBMng()->getDBName()));
+			f1.Insert( CegoFieldValue(VARCHAR_TYPE, _pQueryMng->getDBMng()->getDBName()));
 			f1.Insert( CegoFieldValue(VARCHAR_TYPE, *pTS));
 			f1.Insert( CegoFieldValue(VARCHAR_TYPE, bto.getTabName()));
 			
@@ -671,12 +686,15 @@ void CegoJDBCInfo::handleRequest(const ListT<Chain>& argList) const
 
 	    if ( pTS && pTable )
 	    {
+
+		unsigned tabSetId = _pQueryMng->getDBMng()->getTabSetId(*pTS);
+		
 		CegoTableObject oe;
 
-		if ( _pTabMng->distObjectExists(*pTS, *pTable, CegoObject::TABLE) )
-		    _pTabMng->getDistObject(*pTS, *pTable, CegoObject::TABLE, oe);
-		else if ( _pTabMng->distObjectExists( *pTS, *pTable, CegoObject::VIEW) )
-		    _pTabMng->getDistObject(*pTS, *pTable, CegoObject::VIEW, oe);		    
+		if ( _pQueryMng->objectExists(tabSetId, *pTable, CegoObject::TABLE) )
+		    _pQueryMng->getObject(tabSetId, *pTable, CegoObject::TABLE, oe);
+		else if ( _pQueryMng->objectExists(tabSetId, *pTable, CegoObject::VIEW) )
+		    _pQueryMng->getObject(tabSetId, *pTable, CegoObject::VIEW, oe);		    
 		else
 		{
 		    Chain msg = "Unknown object " + *pTable;
@@ -719,7 +737,7 @@ void CegoJDBCInfo::handleRequest(const ListT<Chain>& argList) const
 		while ( pF )
 		{
 		    ListT<CegoFieldValue> f1;
-		    f1.Insert( CegoFieldValue(VARCHAR_TYPE, _pTabMng->getDBMng()->getDBName()));
+		    f1.Insert( CegoFieldValue(VARCHAR_TYPE, _pQueryMng->getDBMng()->getDBName()));
 		    f1.Insert( CegoFieldValue(VARCHAR_TYPE, *pTS));
 		    f1.Insert( CegoFieldValue(VARCHAR_TYPE, *pTable));
 		    f1.Insert( CegoFieldValue(VARCHAR_TYPE, pF->getAttrName()));
@@ -804,7 +822,7 @@ void CegoJDBCInfo::handleRequest(const ListT<Chain>& argList) const
 	    o.headOut();
 
 	    ListT<CegoFieldValue> t1;
-	    if ( _pTabMng->getAutoCommit() )
+	    if ( _pQueryMng->getAutoCommit() )
 		t1.Insert( CegoFieldValue(BOOL_TYPE, Chain("true")));
 	    else
 		t1.Insert( CegoFieldValue(BOOL_TYPE, Chain("false")));
@@ -823,9 +841,9 @@ void CegoJDBCInfo::handleRequest(const ListT<Chain>& argList) const
 	    o.headOut();
 	    
 	    ListT<CegoFieldValue> t1;
-	    if ( _pTabMng->getIsolationLevel() == CegoTableManager::READ_COMMITTED)
+	    if ( _pQueryMng->getIsolationLevel() == CegoTableManager::READ_COMMITTED)
 		t1.Insert( CegoFieldValue(VARCHAR_TYPE, Chain("read_committed")));
-	    else if ( _pTabMng->getIsolationLevel() == CegoTableManager::READ_UNCOMMITTED)
+	    else if ( _pQueryMng->getIsolationLevel() == CegoTableManager::READ_UNCOMMITTED)
 		t1.Insert( CegoFieldValue(VARCHAR_TYPE, Chain("read_uncommitted")));
 
 	    o.rowOut(t1);	    
