@@ -97,9 +97,9 @@ void CegoJoinObject::setSchema(const ListT<CegoField>& schema)
     _schema = schema;
 }
 
-int CegoJoinObject::getEntrySize() const
+unsigned CegoJoinObject::getEntrySize() const
 {
-    int entrySize = CegoContentObject::getBaseContentSize();
+    unsigned entrySize = CegoContentObject::getBaseContentSize();
 
     entrySize += sizeof(JoinType);
     entrySize += _pLeftObject->getEntrySize();
@@ -115,7 +115,7 @@ int CegoJoinObject::getEntrySize() const
 void CegoJoinObject::encode(char *buf) const
 {    
     char* bufPtr = buf;
-    int entrySize = getEntrySize();
+    unsigned entrySize = getEntrySize();
     CegoContentObject::encodeBaseContent(bufPtr, entrySize);
     bufPtr += CegoContentObject::getBaseContentSize();
     
@@ -140,7 +140,7 @@ void CegoJoinObject::encode(char *buf) const
 void CegoJoinObject::decode(char *buf)
 {    
     char* bufPtr = buf;
-    int size;
+    unsigned size;
     CegoContentObject::decodeBaseContent(bufPtr, size);
     bufPtr += CegoContentObject::getBaseContentSize();
 
@@ -312,7 +312,7 @@ Chain CegoJoinObject::getId(CegoProcBlock *pBlock) const
     return s;
 }
 
-Chain CegoJoinObject::toChain(int defTabSetId) const
+Chain CegoJoinObject::toChain(unsigned defTabSetId) const
 {
     Chain s;
 
