@@ -37,11 +37,11 @@ CegoProcObject::CegoProcObject(const CegoProcObject& po)  : CegoDecodableObject(
     _procText = po._procText;
 }
 
-CegoProcObject::CegoProcObject(const Chain& procName, int tabSetId) : CegoDecodableObject(CegoObject::PROCEDURE, procName, tabSetId)
+CegoProcObject::CegoProcObject(const Chain& procName, unsigned tabSetId) : CegoDecodableObject(CegoObject::PROCEDURE, procName, tabSetId)
 {
 }
 
-CegoProcObject::CegoProcObject(int tabSetId, const Chain& procName, const Chain& procText) : CegoDecodableObject(CegoObject::PROCEDURE, procName, tabSetId)
+CegoProcObject::CegoProcObject(unsigned tabSetId, const Chain& procName, const Chain& procText) : CegoDecodableObject(CegoObject::PROCEDURE, procName, tabSetId)
 {
     _procText = procText;
 }
@@ -50,9 +50,9 @@ CegoProcObject::~CegoProcObject()
 {   
 }
 
-int CegoProcObject::getEntrySize() const
+unsigned CegoProcObject::getEntrySize() const
 {
-    int entrySize = CegoObject::getBaseSize();
+    unsigned entrySize = CegoObject::getBaseSize();
     entrySize += _procText.length() + 1;
     return entrySize;
 }
@@ -60,7 +60,7 @@ int CegoProcObject::getEntrySize() const
 void CegoProcObject::encode(char *buf) const
 {
     char* bufPtr = buf;
-    int entrySize = getEntrySize();
+    unsigned entrySize = getEntrySize();
     CegoObject::encodeBase(bufPtr, entrySize);
     bufPtr += CegoObject::getBaseSize();
     memcpy (bufPtr, (char*)_procText , _procText.length() + 1);
@@ -69,7 +69,7 @@ void CegoProcObject::encode(char *buf) const
 void CegoProcObject::decode(char *buf)
 {
     char* bufPtr = buf;
-    int size;
+    unsigned size;
     CegoObject::decodeBase(bufPtr, size);
     bufPtr += CegoObject::getBaseSize();
     _procText = Chain(bufPtr);
