@@ -54,7 +54,7 @@ void CegoProcThrowStmt::cleanUp()
     _pExpr->cleanUp();
 }
 
-Chain CegoProcThrowStmt::toChain(int defTabSetId, const Chain& indent) const
+Chain CegoProcThrowStmt::toChain(unsigned defTabSetId, const Chain& indent) const
 {
     Chain s;	    
     s =  indent + Chain("throw ") + _pExpr->toChain(defTabSetId);
