@@ -38,7 +38,7 @@ public:
 
     CegoException execute();
     void cleanUp();
-    Chain toChain(int defTabSetId, const Chain& indent) const;
+    Chain toChain(unsigned defTabSetId, const Chain& indent) const;
     Chain dbFormat(CegoDatabaseFormater *pForm) const;
     bool isStatic() const;
     
