@@ -29,7 +29,7 @@
 #include <string.h>
 #include <stdlib.h>
 
-CegoQuery::CegoQuery(CegoDistManager* pGTM, const Chain& tableSet, CegoQuery::TransactionOp to)
+CegoQuery::CegoQuery(CegoQueryManager* pGTM, const Chain& tableSet, CegoQuery::TransactionOp to)
 {
     if ( to == CegoQuery::START )
 	_mode = START_QUERY;
@@ -44,7 +44,7 @@ CegoQuery::CegoQuery(CegoDistManager* pGTM, const Chain& tableSet, CegoQuery::Tr
     _pSelect = 0;
 }
 
-CegoQuery::CegoQuery(CegoDistManager* pGTM, const Chain& tableSet,
+CegoQuery::CegoQuery(CegoQueryManager* pGTM, const Chain& tableSet,
 		     const Chain& tableName,
 		     const ListT<CegoField>& schema,
 		     const ListT<ListT<CegoExpr*> >& exprListArray)
@@ -59,7 +59,7 @@ CegoQuery::CegoQuery(CegoDistManager* pGTM, const Chain& tableSet,
     _pPred = 0;
 }
 
-CegoQuery::CegoQuery(CegoDistManager* pGTM, const Chain& tableSet,
+CegoQuery::CegoQuery(CegoQueryManager* pGTM, const Chain& tableSet,
 		     const Chain& tableName,
 		     const ListT<CegoField>& schema,
 		     CegoSelect *pSelect)
@@ -73,7 +73,7 @@ CegoQuery::CegoQuery(CegoDistManager* pGTM, const Chain& tableSet,
     _pPred = 0;
 }
 
-CegoQuery::CegoQuery(CegoDistManager* pGTM, const Chain& tableSet,
+CegoQuery::CegoQuery(CegoQueryManager* pGTM, const Chain& tableSet,
 		     const Chain& tableName,
 		     const Chain& tableAlias,
 		     CegoPredicate* pPred)
@@ -87,7 +87,7 @@ CegoQuery::CegoQuery(CegoDistManager* pGTM, const Chain& tableSet,
     _pSelect = 0;    
 }
 
-CegoQuery::CegoQuery(CegoDistManager* pGTM, const Chain& tableSet,
+CegoQuery::CegoQuery(CegoQueryManager* pGTM, const Chain& tableSet,
 		     const Chain& tableName,
 		     const Chain& tableAlias,
 		     CegoPredicate* pPred,
@@ -109,7 +109,7 @@ CegoQuery::CegoQuery(CegoDistManager* pGTM, const Chain& tableSet,
     _returnOnFirst = returnOnFirst;
 }
 
-CegoQuery::CegoQuery(CegoDistManager* pGTM, const Chain& tableSet,
+CegoQuery::CegoQuery(CegoQueryManager* pGTM, const Chain& tableSet,
 		     const Chain& tableName,
 		     bool doLock)
 {
@@ -124,7 +124,7 @@ CegoQuery::CegoQuery(CegoDistManager* pGTM, const Chain& tableSet,
     _pSelect = 0;
 }
 
-CegoQuery::CegoQuery(CegoDistManager* pGTM, const Chain& tableSet,
+CegoQuery::CegoQuery(CegoQueryManager* pGTM, const Chain& tableSet,
 		     const Chain& tableName,
 		     const ListT<CegoAlterDesc>& alterList)
 {
@@ -137,7 +137,7 @@ CegoQuery::CegoQuery(CegoDistManager* pGTM, const Chain& tableSet,
     _pSelect = 0;
 }
 
-CegoQuery::CegoQuery(CegoDistManager* pGTM, const Chain& tableSet,
+CegoQuery::CegoQuery(CegoQueryManager* pGTM, const Chain& tableSet,
 		     const Chain& objName,
 		     CegoObject::ObjectType objType,
 		     const Chain& newObjName )
@@ -221,7 +221,7 @@ Chain CegoQuery::execute(CegoProcBlock *pBlock)
     {
 	try
 	{
-	    _pGTM->startDistTransaction(_tableSet);
+	    _pGTM->startTransaction(_tableSet);
 	}
 	catch ( Exception e )
 	{
@@ -234,7 +234,7 @@ Chain CegoQuery::execute(CegoProcBlock *pBlock)
 	long opCount = 0;
 	try
 	{
-	    opCount = _pGTM->endDistTransaction(_tableSet);
+	    opCount = _pGTM->endTransaction(_tableSet);
 	}
 	catch ( Exception e )
 	{
@@ -248,7 +248,7 @@ Chain CegoQuery::execute(CegoProcBlock *pBlock)
 	long opCount = 0;
 	try
 	{
-	    opCount = _pGTM->rollbackDistTransaction(_tableSet);
+	    opCount = _pGTM->rollbackTransaction(_tableSet);
 	}
 	catch ( Exception e )
 	{
@@ -289,9 +289,9 @@ Chain CegoQuery::execute(CegoProcBlock *pBlock)
     {	
 	if ( _pGTM->getAutoCommit() == false )
 	{
-	    if ( _pGTM->getDistTid(_tableSet) == 0 )
+	    if ( _pGTM->getTid(_tableSet) == 0 )
 	    {
-		_pGTM->startDistTransaction(_tableSet);
+		_pGTM->startTransaction(_tableSet);
 	    }
 	}
 
@@ -305,10 +305,10 @@ Chain CegoQuery::execute(CegoProcBlock *pBlock)
 	    if ( _pGTM->objectExists(tabSetId, _tableName, CegoObject::ALIAS ))
 	    {
 		CegoAliasObject ao;
-		_pGTM->getDistObject(_tableSet, _tableName, CegoObject::ALIAS, ao);
+		_pGTM->getObject(tabSetId, _tableName, CegoObject::ALIAS, ao);
 
 		// get table object for alias
-		_pGTM->getDistObject(_tableSet, ao.getTabName(), CegoObject::TABLE, oe);
+		_pGTM->getObject(tabSetId, ao.getTabName(), CegoObject::TABLE, oe);
 
 		if (  execSchema.isEmpty() )
 		{
@@ -324,7 +324,7 @@ Chain CegoQuery::execute(CegoProcBlock *pBlock)
 	    }
 	    else
 	    {
-		_pGTM->getDistObject(_tableSet, _tableName, CegoObject::TABLE, oe);
+		_pGTM->getObject(tabSetId, _tableName, CegoObject::TABLE, oe);
 	    }
 	}
 	catch ( Exception e )
@@ -469,7 +469,7 @@ Chain CegoQuery::execute(CegoProcBlock *pBlock)
 	    
 	    try
 	    {				
-		_pGTM->insertDistDataTable(oe, fva);
+		_pGTM->insertQueryTable(oe, fva);
 
 		_pGTM->getDBMng()->cleanCache( oe.getTabSetId(), CegoObject::TABLE, oe.getTabName());
 		
@@ -537,9 +537,9 @@ Chain CegoQuery::execute(CegoProcBlock *pBlock)
 	{
 	    if ( _pGTM->getAutoCommit() == false )
 	    {
-		if ( _pGTM->getDistTid(_tableSet) == 0 )
+		if ( _pGTM->getTid(_tableSet) == 0 )
 		{
-		    _pGTM->startDistTransaction(_tableSet);
+		    _pGTM->startTransaction(_tableSet);
 		}
 	    }
 	    
@@ -547,16 +547,16 @@ Chain CegoQuery::execute(CegoProcBlock *pBlock)
 	    if ( _pGTM->objectExists(tabSetId, _tableName, CegoObject::ALIAS ))
 	    {
 		CegoAliasObject ae;
-		_pGTM->getDistObject(_tableSet, _tableName, CegoObject::ALIAS, ae);
+		_pGTM->getObject(tabSetId, _tableName, CegoObject::ALIAS, ae);
 
 		CegoQueryHelper::mapAliasSchema(execSchema, ae.getAliasList());
 		
 		// get table object for alias
-		_pGTM->getDistObject(_tableSet, ae.getTabName(), CegoObject::TABLE, oe);
+		_pGTM->getObject(tabSetId, ae.getTabName(), CegoObject::TABLE, oe);
 	    }
 	    else
 	    {
-		_pGTM->getDistObject(_tableSet, _tableName, CegoObject::TABLE, oe);
+		_pGTM->getObject(tabSetId, _tableName, CegoObject::TABLE, oe);
 	    }
 	}
 	catch ( Exception e )
@@ -675,7 +675,7 @@ Chain CegoQuery::execute(CegoProcBlock *pBlock)
 		{
 		    try
 		    {
-			_pGTM->insertDistDataTable(oe, fva);
+			_pGTM->insertQueryTable(oe, fva);
 			_affCount += fva.Size();
 			fva.Empty();
 		    }
@@ -746,9 +746,9 @@ Chain CegoQuery::execute(CegoProcBlock *pBlock)
 	{
 	    if ( _pGTM->getAutoCommit() == false )
 	    {
-		if ( _pGTM->getDistTid(_tableSet) == 0 )
+		if ( _pGTM->getTid(_tableSet) == 0 )
 		{
-		    _pGTM->startDistTransaction(_tableSet);
+		    _pGTM->startTransaction(_tableSet);
 		}
 	    }
 
@@ -758,20 +758,20 @@ Chain CegoQuery::execute(CegoProcBlock *pBlock)
 	    if ( _pGTM->objectExists(tabSetId, _tableName, CegoObject::ALIAS ))
 	    {
 		CegoAliasObject ae;
-		_pGTM->getDistObject(_tableSet, _tableName, CegoObject::ALIAS, ae);
+		_pGTM->getObject(tabSetId, _tableName, CegoObject::ALIAS, ae);
 
 		CegoQueryHelper::mapAliasPredicate(_pPred, _tableAlias, ae.getAliasList());
 		
 		// get table object for alias
-		_pGTM->getDistObject(_tableSet, ae.getTabName(), CegoObject::TABLE, oe);
+		_pGTM->getObject(tabSetId, ae.getTabName(), CegoObject::TABLE, oe);
 	    }
 	    else
 	    {
-		_pGTM->getDistObject(_tableSet, _tableName, CegoObject::TABLE, oe);
+		_pGTM->getObject(tabSetId, _tableName, CegoObject::TABLE, oe);
 	    }
 	    
 	    oe.setTabAlias(_tableAlias);
-	    _affCount = _pGTM->deleteDistDataTable(oe, _pPred, pBlock);
+	    _affCount = _pGTM->deleteQueryTable(oe, _pPred, pBlock);
 	    _pGTM->getDBMng()->cleanCache(oe.getTabSetId(), CegoObject::TABLE, oe.getTabName() );
 	}
 	catch ( Exception e )
@@ -791,9 +791,9 @@ Chain CegoQuery::execute(CegoProcBlock *pBlock)
 	{
 	    if ( _pGTM->getAutoCommit() == false )
 	    {
-		if ( _pGTM->getDistTid(_tableSet) == 0 )
+		if ( _pGTM->getTid(_tableSet) == 0 )
 		{
-		    _pGTM->startDistTransaction(_tableSet);
+		    _pGTM->startTransaction(_tableSet);
 		}
 	    }
 	    
@@ -801,17 +801,17 @@ Chain CegoQuery::execute(CegoProcBlock *pBlock)
 	    if ( _pGTM->objectExists(tabSetId, _tableName, CegoObject::ALIAS ))
 	    {
 		CegoAliasObject ae;
-		_pGTM->getDistObject(_tableSet, _tableName, CegoObject::ALIAS, ae);
+		_pGTM->getObject(tabSetId, _tableName, CegoObject::ALIAS, ae);
 
 		CegoQueryHelper::mapAliasPredicate(_pPred, _tableAlias, ae.getAliasList());
 		CegoQueryHelper::mapAliasSchema(execSchema, ae.getAliasList());
 		
 		// get table object for alias
-		_pGTM->getDistObject(_tableSet, ae.getTabName(), CegoObject::TABLE, oe);
+		_pGTM->getObject(tabSetId, ae.getTabName(), CegoObject::TABLE, oe);
 	    }
 	    else
 	    {
-		_pGTM->getDistObject(_tableSet, _tableName, CegoObject::TABLE, oe);
+		_pGTM->getObject(tabSetId, _tableName, CegoObject::TABLE, oe);
 	    }
 	}
 	catch ( Exception e )
@@ -850,7 +850,7 @@ Chain CegoQuery::execute(CegoProcBlock *pBlock)
 	
 	try 
 	{
-	    _affCount = _pGTM->updateDistDataTable(oe, _pPred, execSchema, _updList, _returnOnFirst, returnList,  pBlock);
+	    _affCount = _pGTM->updateQueryTable(oe, _pPred, execSchema, _updList, _returnOnFirst, returnList,  pBlock);
 	    _pGTM->getDBMng()->cleanCache( oe.getTabSetId(), CegoObject::TABLE, oe.getTabName());
 	}
 	catch ( Exception e )
@@ -887,10 +887,12 @@ Chain CegoQuery::execute(CegoProcBlock *pBlock)
  
 	CegoTableObject oe;
 
+	unsigned tabSetId = _pGTM->getDBMng()->getTabSetId(_tableSet);
+		    
 	try
 	{
-	    _pGTM->getDistObject(_tableSet, _tableName, CegoObject::TABLE, oe);
-	    _pGTM->alterDistDataTable(oe, _alterList);
+	    _pGTM->getObject(tabSetId, _tableName, CegoObject::TABLE, oe);
+	    _pGTM->alterQueryTable(oe, _alterList);
 	    _affCount++;
 	    _pGTM->getDBMng()->cleanCache(oe.getTabSetId(), CegoObject::TABLE, oe.getTabName());
 	}
@@ -904,6 +906,8 @@ Chain CegoQuery::execute(CegoProcBlock *pBlock)
     case RENAME_QUERY:
     {
 	// rename query is not transaction safe
+
+	unsigned tabSetId = _pGTM->getDBMng()->getTabSetId(_tableSet);
 	
 	if ( _objType == CegoObject::TABLE )
 	{
@@ -911,7 +915,7 @@ Chain CegoQuery::execute(CegoProcBlock *pBlock)
 	    
 	    try
 	    {		
-		_pGTM->getDistObject(_tableSet, _objName, _objType, oe);	
+		_pGTM->getObject(tabSetId, _objName, _objType, oe);	
 	    }
 	    catch ( Exception e )
 	    {
@@ -924,7 +928,7 @@ Chain CegoQuery::execute(CegoProcBlock *pBlock)
 	
 	try 
 	{
-	    _pGTM->renameDistObject(_tableSet, _objName, _objType, _newObjName);
+	    _pGTM->renameQueryObject(_tableSet, _objName, _objType, _newObjName);
 	    _affCount++;
 	}
 	catch ( Exception e )
