@@ -34,24 +34,24 @@ class CegoQueryCache {
 
 public:
 
-    CegoQueryCache(int tabSetId, int maxEntry, int maxSize, int threshold, int hashRange);
+    CegoQueryCache(unsigned tabSetId, unsigned maxEntry, unsigned maxSize, unsigned threshold, unsigned hashRange);
     ~CegoQueryCache();
     
     Element* getCacheInfo();
     Element* getCacheList();
-    int getMaxEntry() const;
-    int getMaxSize() const;
-    int getThreshold() const;
-    int getNumQueryCache() const;
+    unsigned getMaxEntry() const;
+    unsigned getMaxSize() const;
+    unsigned getThreshold() const;
+    unsigned getNumQueryCache() const;
     unsigned long long getUsedSize() const;
     double getHitRate() const;
-    int getNumFail() const;
+    unsigned getNumFail() const;
     void invalidate(const CegoObject& td);
-    CegoFieldValue*** claimEntry(const Chain& queryId, ListT<CegoField>& cacheSchema, int& cacheRows);
+    CegoFieldValue*** claimEntry(const Chain& queryId, ListT<CegoField>& cacheSchema, unsigned& cacheRows);
     void releaseEntry(const Chain& queryId);
     bool addEntry(const Chain& queryId, const SetT<CegoObject>& objList, ListT< ListT<CegoFieldValue> >* pCacheList, const ListT<CegoField>& cacheSchema);
     void clean();
-    void getQCLockStat(int& lockCount, unsigned long long &numRdLock, unsigned long long &numWrLock, unsigned long long &sumRdDelay, unsigned long long &sumWrDelay);
+    void getQCLockStat(unsigned& lockCount, unsigned long long &numRdLock, unsigned long long &numWrLock, unsigned long long &sumRdDelay, unsigned long long &sumWrDelay);
     
 private:
     
@@ -64,14 +64,14 @@ private:
 	QueryCacheEntry(const Chain& queryId, const SetT<CegoObject>& objectList, ListT< ListT<CegoFieldValue> >* pCacheList, const ListT<CegoField>& cacheSchema);
 	~QueryCacheEntry();
 
-	int getSize() const;
+	unsigned getSize() const;
 	
-	int getHashPos(int hashSize) const;
+	unsigned getHashPos(unsigned hashSize) const;
 
 	bool cleanCache();
 	const Chain getQueryId() const;
-	int getNumRows() const;
-	int getNumUsed() const;
+	unsigned getNumRows() const;
+	unsigned getNumUsed() const;
 
 	const SetT<CegoObject>& getObjectList() const;
 
@@ -101,25 +101,25 @@ private:
 	CegoFieldValue*** _pCacheArray;
 	ListT<CegoField> _cacheSchema;
 	unsigned long _numHit;
-	int _numRow;
-	int _numCol;
-	int _numUsed;
-	int _size;
+	unsigned _numRow;
+	unsigned _numCol;
+	unsigned _numUsed;
+	unsigned _size;
     };
 
     void PR();
     void PW();
     void V();
 
-    int _tabSetId;
-    int _maxEntry;
-    int _threshold;
-    int _maxSize;
-    int _hashRange;
+    unsigned _tabSetId;
+    unsigned _maxEntry;
+    unsigned _threshold;
+    unsigned _maxSize;
+    unsigned _hashRange;
     unsigned long long _usedSize;
-    int _numFail;
-    int _numTry;
-    int _numHit;
+    unsigned _numFail;
+    unsigned _numTry;
+    unsigned _numHit;
     HashT<QueryCacheEntry>* _pQueryCache;
 };
 #endif
