@@ -319,28 +319,27 @@ void CegoQueryCursor::querySetup(ListT<CegoField>** pFLA, CegoPredicate* pPred)
 	
 	CegoJoinObject *pJO = (CegoJoinObject*)_pCO;
 	
-	if ( pJO->getJoinType() == CegoJoinObject::INNER )
+	// if ( pJO->getJoinType() == CegoJoinObject::INNER )
+	// {
+	Chain leftAlias = pJO->getLeftObject()->getTabAlias();
+	
+	ListT<Chain> aliasList;
+	if ( pJO->getLeftObject()->getType() != CegoObject::JOIN )
+	    aliasList.Insert(leftAlias);
+	else
 	{
-	    Chain leftAlias = pJO->getLeftObject()->getTabAlias();
-
-	    ListT<Chain> aliasList;
-	    if ( pJO->getLeftObject()->getType() != CegoObject::JOIN )
-		aliasList.Insert(leftAlias);
-	    else
-	    {
-		ListT<Chain> subList = pJO->getSubAliasList();
-		aliasList += subList;
-	    }
-	    
-	    
-	    Chain rightAlias = pJO->getRightObject()->getTabAlias();
-	    if ( pJO->getRightObject()->getType() != CegoObject::JOIN )
-		aliasList.Insert(rightAlias);
-
-	    // cout << "1 Setting up cursor " << _tableAlias << " pred for " << leftAlias << " and " << rightAlias << endl;
-	    _pJoinPred = pPred->getReduced(aliasList);
-	    
+	    ListT<Chain> subList = pJO->getSubAliasList();
+	    aliasList += subList;
 	}
+	
+	
+	Chain rightAlias = pJO->getRightObject()->getTabAlias();
+	if ( pJO->getRightObject()->getType() != CegoObject::JOIN )
+	    aliasList.Insert(rightAlias);
+	
+	// cout << "1 Setting up cursor " << _tableAlias << " pred for " << leftAlias << " and " << rightAlias << endl;
+	_pJoinPred = pPred->getReduced(aliasList);
+	    
     }
     else
     {	
@@ -435,38 +434,36 @@ void CegoQueryCursor::querySetup( CegoAttrCond& attrCond, ListT<CegoField>** pFL
     _idxMatch = CegoAttrCond::INAPP;
     _isFirst=true;
     _doEval = false;
-
+    
     if (  pPred &&  ( _pCO->getType() == CegoObject::TABLE || _pCO->getType() == CegoObject::VIEW  || _pCO->getType() == CegoObject::ALIAS)  )
     {
-	// cout << "Reducing " << pPred->toChain(0) << " for " << _tableAlias << endl;
+
 	_pPropPred = pPred->getReduced(_tableAlias);
-	// if ( _pPropPred )
+	//if ( _pPropPred )
 	//     cout << " => " << _pPropPred->toChain(0) << endl;
 	_pJoinPred = _pPropPred;
     }
     else if ( pPred && _pCO->getType() == CegoObject::JOIN )
-    {	
+    {
+
 	// set up for further propagation
 	_pPropPred = pPred;
 	
 	CegoJoinObject *pJO = (CegoJoinObject*)_pCO;
+
+	Chain leftAlias = pJO->getLeftObject()->getTabAlias();
 	
-	if ( pJO->getJoinType() == CegoJoinObject::INNER )
-	{
-	    Chain leftAlias = pJO->getLeftObject()->getTabAlias();
-
-	    ListT<Chain> aliasList;
-	    if ( pJO->getLeftObject()->getType() != CegoObject::JOIN )
-		aliasList.Insert(leftAlias);
-	    
-	    Chain rightAlias = pJO->getRightObject()->getTabAlias();
-	    if ( pJO->getRightObject()->getType() != CegoObject::JOIN )
+	ListT<Chain> aliasList;
+	if ( pJO->getLeftObject()->getType() != CegoObject::JOIN )
+	    aliasList.Insert(leftAlias);
+	
+	Chain rightAlias = pJO->getRightObject()->getTabAlias();
+	if ( pJO->getRightObject()->getType() != CegoObject::JOIN )
 		aliasList.Insert(rightAlias);
-
-	    // cout << "2 Setting up cursor " << _tableAlias << " pred for " << leftAlias << " and " << rightAlias << endl;
-	    _pJoinPred = pPred->getReduced(aliasList);
-
-	}
+	
+	// cout << "2 Setting up cursor " << _tableAlias << " pred for " << leftAlias << " and " << rightAlias << endl;
+	_pJoinPred = pPred->getReduced(aliasList);
+		
     }
     else
     {
@@ -607,8 +604,7 @@ bool CegoQueryCursor::nextTuple(ListT<CegoField>** pFLA, unsigned pos, unsigned
     useCursorObject();
     
     while ( getTuple(pFLA, pos, size) )
-    {
-	
+    {	
 	/*
 	cout << "### " << _tableAlias << " TUPLE = ";
 	for ( int i=0; i<size; i++)
@@ -626,17 +622,18 @@ bool CegoQueryCursor::nextTuple(ListT<CegoField>** pFLA, unsigned pos, unsigned
 
 	bool evaluated=true;
 
+	
 	// first step : if required, evaluate join condition 
 	if ( _doEval == true )
-	{
+	{	    
 	    evaluated =  evalCondition(pFLA, pos, size);
 	}
+
 	
 	// cout << "Eval join pred ? " << endl; 
 	// second step : if available, evaluate propagated master predicate
 	if ( evaluated && _pJoinPred )
 	{
-	    // cout << "Eval  " << _pJoinPred->toChain(0) << " for " << _tableAlias << endl; 
 	    evaluated =  _pJoinPred->eval(_pFLA,
 					  0,
 					  pFLA,
@@ -649,7 +646,7 @@ bool CegoQueryCursor::nextTuple(ListT<CegoField>** pFLA, unsigned pos, unsigned
 	    
 #ifdef CGDEBUG
 	    _pDBMng->log(_modId, Logger::DEBUG, Chain("Cursor ") + _tableAlias + Chain(" returns tuple"));
-#endif	    
+#endif
 	    return true;
 	}    
     }
@@ -658,7 +655,6 @@ bool CegoQueryCursor::nextTuple(ListT<CegoField>** pFLA, unsigned pos, unsigned
 
 bool CegoQueryCursor::evalCondition(ListT<CegoField>** pFLA, unsigned pos, unsigned size)
 {
-    
     if ( _cursorCond.numComp() == 0 )
 	return true;
     
@@ -1428,7 +1424,7 @@ bool CegoQueryCursor::getTuple(ListT<CegoField>** pFLA, unsigned offset, unsigne
 }
 
 void CegoQueryCursor::nextRight(ListT<CegoField>** pFLA, unsigned offset, unsigned size)
-{
+{    
     CegoJoinObject *pJO = (CegoJoinObject*)_pCO;
 	
     _moreRight = _pTCRight->nextTuple(pFLA, offset+size-1, 1);
@@ -1453,7 +1449,6 @@ void CegoQueryCursor::nextRight(ListT<CegoField>** pFLA, unsigned offset, unsign
 	
 	if ( isValid && _pJoinPred )
 	{
-
 	    isValid = _pJoinPred->eval(_pFLA,
 				       0,
 				       pFLA,
@@ -1471,6 +1466,7 @@ void CegoQueryCursor::nextRight(ListT<CegoField>** pFLA, unsigned offset, unsign
 	    _moreRight = _pTCRight->nextTuple(pFLA, offset+size-1, 1);
 	}			      
     }
+    
 }
 
 void CegoQueryCursor::nextLeft(ListT<CegoField>** pFLA, unsigned offset, unsigned size)
