@@ -31,8 +31,8 @@ class CegoQueryException : public Exception {
 
 public:
   
-    CegoQueryException(CegoException excep, const Chain& module, int line, const Chain& msg);
-    CegoQueryException(CegoException excep, const Chain& module, int line, const Chain& msg, const Exception& e);
+    CegoQueryException(CegoException excep, const Chain& module, unsigned line, const Chain& msg);
+    CegoQueryException(CegoException excep, const Chain& module, unsigned line, const Chain& msg, const Exception& e);
     ~CegoQueryException();
     
     CegoException getException() const;
