@@ -44,45 +44,16 @@ CegoRecoveryManager::~CegoRecoveryManager()
 unsigned long long CegoRecoveryManager::startRecovery(const Chain& tableSet)
 {
 
+    Chain status = _pDBMng->getTableSetRunState(tableSet);
+    if ( status != Chain(XML_OFFLINE_VALUE) )
+    {
+	throw Exception(EXLOC, Chain("Cannot start recovery of tableset in status ") + status);
+    }
+
     unsigned tabSetId = _pDBMng->getTabSetId(tableSet);
 
     _pDBMng->setRecoveryMode(tabSetId, CegoDatabaseManager::ON);
-
-    Chain tsTicketName = _pDBMng->getTSTicket(tableSet);
     
-    File tsTicket(tsTicketName);
-    if ( tsTicket.exists() ) 
-    {
-	tsTicket.open(File::READ);
-	
-	XMLSuite xml;
-	
-	Document *pDoc = new Document;
-	pDoc->setAttribute(XML_VERSION_ATTR, XML_VERSION_VALUE);
-	
-	xml.setDocument(pDoc);    
-	xml.setFile(&tsTicket);
-	
-	xml.parse();
-	
-	Element *pRoot = pDoc->getRootElement();
-	pDoc->setRootElement(0);
-	delete pDoc;
-		
-	_pDBMng->setTableSetInfo(tableSet, pRoot);
-	
-	tsTicket.close();
-    
-#ifdef CGDEBUG	
-	_pDBMng->log(_modId, Logger::DEBUG, Chain("Removing backup ticket ") + tsTicket.getFileName() + Chain(" ..."));
-#endif
-	    
-	tsTicket.remove();
-	
-	// after ticket restore, we have to set tabSetId to current tableset value
-	tabSetId = _pDBMng->getTabSetId(tableSet);
-    }
-
     // we have to set tableset run state AFTER ticket restore
     _pDBMng->setTableSetRunState(tableSet, XML_RECOVERY_VALUE);
    
@@ -206,10 +177,21 @@ unsigned long long CegoRecoveryManager::recoverTableSet(const Chain& tableSet, l
     
     unsigned tabSetId = _pDBMng->getTabSetId(tableSet);
 
-
     try
     {	
-		
+
+	// we first have to check, if file recovery is needed 
+	bool needFileRecovery=false;
+	
+	Chain status = _pDBMng->getTableSetRunState(tableSet);
+	if ( status == Chain(XML_INCOMPLETE_VALUE) )
+	{
+	    needFileRecovery=true;
+	}
+	
+	// now we can set state to recovery, this is needed to release log files
+	_pDBMng->setTableSetRunState(tableSet, XML_RECOVERY_VALUE);
+	
 	if ( pAH ) 
 	    pAH->syncWithInfo(Chain("local"), Chain("local"), Chain("Releasing log files ...\n")); 
 	_pDBMng->releaseLogFiles(tableSet, true);
@@ -220,69 +202,7 @@ unsigned long long CegoRecoveryManager::recoverTableSet(const Chain& tableSet, l
             pAH->syncWithInfo(Chain("local"), Chain("local"), Chain("Stopping log ...\n")); 
 	_pDBMng->stopLog(tabSetId);	
 
-		
-	Chain tsTicketName = _pDBMng->getTSTicket(tableSet);
 
-	bool needFileRecovery=false;
-	File tsTicket(tsTicketName);
-	if ( tsTicket.exists() ) 
-	{
-
-	    needFileRecovery=true;
-	    
-	    _pDBMng->log(_modId, Logger::NOTICE, Chain("Backup tableset ticket detected, datafile file recovery required ..."));
-	    tsTicket.open(File::READ);
-	    
-	    XMLSuite xml;
-	    
-	    Document *pDoc = new Document;
-	    pDoc->setAttribute(XML_VERSION_ATTR, XML_VERSION_VALUE);
-	    
-	    xml.setDocument(pDoc);    
-	    xml.setFile(&tsTicket);
-	    
-	    xml.parse();
-	    
-	    Element *pRoot = pDoc->getRootElement();
-	    pDoc->setRootElement(0);
-	    delete pDoc;
-	    
-	    //  we have to check branchId consistency
-	    
-	    Chain buId = pRoot->getAttributeValue(XML_BRANCHID_ATTR);
-	    Chain currentId = _pDBMng->getTableSetBackupBranch(tableSet);
-	    
-	    if ( buId == currentId )
-		_pDBMng->log(_modId, Logger::NOTICE, Chain("Backup branch id ") + buId + Chain(" for ticket file verified"));
-	    else
-	    {
-		delete pRoot;
-			
-		Chain msg = Chain("Backup branch mismatch : <") + buId + Chain("> != <") + currentId + Chain(">");
-		
-		// _pDBMng->setRecoveryMode(tabSetId, CegoDatabaseManager::OFF );
-		_pDBMng->log(_modId, Logger::LOGERR, msg);
-		
-		throw Exception(EXLOC, msg);
-	    }
-	    
-	    _pDBMng->setTableSetInfo(tableSet, pRoot);
-	    
-	    tsTicket.close();
-    
-#ifdef CGDEBUG	
-	    _pDBMng->log(_modId, Logger::DEBUG, Chain("Removing backup ticket ") + tsTicket.getFileName() + Chain(" ..."));
-#endif
-	    
-	    tsTicket.remove();
-
-	    // after ticket restore, we have to set tabSetId to current tableset value
-	    tabSetId = _pDBMng->getTabSetId(tableSet);
-	}
-
-	// we have to set tableset run state AFTER ticket restore
-	_pDBMng->setTableSetRunState(tableSet, XML_RECOVERY_VALUE);
-	
 	// register data files, this is also needed for data file recovery
 	
 	if ( pAH ) 
