@@ -36,11 +36,11 @@ public:
 
     Chain getId() const;
 
-    int replace(const Chain& src, Chain& target);
+    unsigned replace(const Chain& src, Chain& target);
 
     void clean();
 
-    int getHashPos(int hashSize) const;
+    unsigned getHashPos(unsigned  hashSize) const;
     
     CegoReplacer& operator = ( const CegoReplacer& rp);
     bool operator == ( const CegoReplacer& rp);
