@@ -29,7 +29,7 @@
 #include "CegoFieldValue.h"
 #include "CegoFactor.h"
 
-class CegoDistManager;
+class CegoQueryManager;
 
 class CegoTerm {
     
@@ -38,7 +38,7 @@ public:
     enum TermType { MUL, DIV, FACTOR  };
     
     CegoTerm();
-    CegoTerm(char* buf, CegoDistManager *pGTM, CegoProcBlock *pBlock, unsigned tabSetId);
+    CegoTerm(char* buf, CegoQueryManager *pGTM, CegoProcBlock *pBlock, unsigned tabSetId);
     CegoTerm(CegoTerm *pTerm, CegoFactor *pFac, TermType termType);
     CegoTerm(CegoFactor *pFactor);
     ~CegoTerm();
@@ -70,7 +70,7 @@ public:
     Chain dbFormat(CegoDatabaseFormater *pForm) const;
 
     void encode(char *buf, CegoProcBlock *pBlock);
-    void decode(char *buf, CegoDistManager *pGTM, CegoProcBlock *pBlock, unsigned tabSetId);
+    void decode(char *buf, CegoQueryManager *pGTM, CegoProcBlock *pBlock, unsigned tabSetId);
     unsigned getEncodingLength(CegoProcBlock *pBlock) const;
 
     void getPlanList(ListT<Element*>& planList);
