@@ -176,11 +176,9 @@ public:
     void doc2Xml();
     void initDoc();
     void setTSRoot(const Chain& tableSet, const Chain& tsRoot);
-    Chain getTSRoot(const Chain& tableSet);    
+    Chain getTSRoot(const Chain& tableSet) const;    
     void nextTableSetBackupBranch(const Chain& tableSet);
     Chain getTableSetBackupBranch(const Chain& tableSet);
-    void setTSTicket(const Chain& tableSet, const Chain& tsTicket);
-    Chain getTSTicket(const Chain& tableSet);
     unsigned long long getTID(const Chain& tableSet);
     bool tableSetExists(const Chain& tableSet);
     void setTSSortAreaSize(const Chain& tabSetName, unsigned long long sortAreaSize);
