@@ -26,7 +26,7 @@
 // cego includes
 #include "CegoDefs.h"
 #include "CegoBufferPool.h"
-#include "CegoDistManager.h"
+#include "CegoQueryManager.h"
 #include "CegoAdminHandler.h"
 #include "CegoPredicate.h"
 
@@ -35,7 +35,7 @@ class CegoXPorter {
     
  public:
 
-    CegoXPorter(CegoDistManager *pGTM, CegoAdminHandler *pAH = 0);
+    CegoXPorter(CegoQueryManager *pGTM, CegoAdminHandler *pAH = 0);
     ~CegoXPorter();
 
     void xmlImportTableSet(const Chain& tableSet, bool isStructure, const Chain& impFile);
@@ -81,7 +81,7 @@ class CegoXPorter {
     void readRow(File *pInFile, unsigned tabSetId, const Chain& tableName, const ListT<CegoField>& rowSchema);
 
     BinTag _tag;
-    CegoDistManager *_pGTM;
+    CegoQueryManager *_pGTM;
     CegoDatabaseManager *_pDBMng;
     CegoAdminHandler *_pAH;
     CegoTableObject _oe;
